@@ -23,31 +23,23 @@
 #ifndef __HASH_TABLE_H
 #define __HASH_TABLE_H
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#include "aterm2.h"
+#include "mcrl2/aterm/aterm2.h"
 #include "ptable.h"
 
   typedef struct
   {
-    ATermIndexedSet terms;
+    aterm::ATermIndexedSet terms;
     PTable pointers;
   } HTable;
 
   int HTinit(HTable*);
   void HTfree(HTable*);
-  unsigned int HTinsert(HTable*, ATerm, void*);
-  int HTmember(HTable*, ATerm, long*);
-  ATerm HTgetTerm(HTable*, long);
+  unsigned int HTinsert(HTable*, aterm::ATerm, void*);
+  int HTmember(HTable*, aterm::ATerm, long*);
+  aterm::ATerm HTgetTerm(HTable*, long);
   void* HTgetPtr(HTable*, long);
   void HTsetPtr(HTable*, long, void*);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
 
 
