@@ -22,10 +22,6 @@
 
 #include <stdlib.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 
 #define PT_INITIALSIZE 1024
 
@@ -42,7 +38,3 @@ extern "C" {
   void* PTget(PTable*, long index);
   void PTfree(PTable*);
 
-#ifdef __cplusplus
-}
-#endif
-
