@@ -25,15 +25,9 @@
 #ifndef _SVC_H
 #define _SVC_H
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#include "aterm1.h"
+#include "mcrl2/aterm/aterm1.h"
 #include "svc1.h"
 
-
-
   typedef SVCint SVCstateIndex;
   typedef SVCint SVClabelIndex;
   typedef SVCint SVCparameterIndex;
@@ -50,21 +44,21 @@ extern "C" {
 
   /* Datatype 'SVClabel' */
 
-  SVClabelIndex SVCnewLabel(SVCfile*, ATerm, SVCbool*);
-  SVClabelIndex SVCaterm2Label(SVCfile*, ATerm);
-  ATerm SVClabel2ATerm(SVCfile*, SVClabelIndex);
+  SVClabelIndex SVCnewLabel(SVCfile*, aterm::ATerm, SVCbool*);
+  SVClabelIndex SVCaterm2Label(SVCfile*, aterm::ATerm);
+  aterm::ATerm SVClabel2ATerm(SVCfile*, SVClabelIndex);
 
   /* Datatype 'SVCstate' */
 
-  SVCstateIndex SVCnewState(SVCfile*, ATerm, SVCbool*);
-  SVCstateIndex SVCaterm2State(SVCfile*, ATerm);
-  ATerm SVCstate2ATerm(SVCfile*, SVCstateIndex);
+  SVCstateIndex SVCnewState(SVCfile*, aterm::ATerm, SVCbool*);
+  SVCstateIndex SVCaterm2State(SVCfile*, aterm::ATerm);
+  aterm::ATerm SVCstate2ATerm(SVCfile*, SVCstateIndex);
 
   /* Datatype 'SVCparameter' */
 
-  SVCparameterIndex SVCnewParameter(SVCfile*, ATerm, SVCbool*);
-  SVCparameterIndex SVCaterm2Parameter(SVCfile*, ATerm);
-  ATerm SVCparameter2ATerm(SVCfile*, SVCparameterIndex);
+  SVCparameterIndex SVCnewParameter(SVCfile*, aterm::ATerm, SVCbool*);
+  SVCparameterIndex SVCaterm2Parameter(SVCfile*, aterm::ATerm);
+  aterm::ATerm SVCparameter2ATerm(SVCfile*, SVCparameterIndex);
 
   /* Datatype 'SVCTransition' */
 
@@ -101,10 +95,6 @@ extern "C" {
   SVCint SVCnumParameters(SVCfile*);
   SVCint SVCnumTransitions(SVCfile*);
 
-  char* SVCerror(int);
-
-#ifdef __cplusplus
-}
-#endif
+  std::string SVCerror(int);
 
 #endif
