@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-   $Id: lz.cpp 9724 2011-10-11 07:18:00Z jkeiren $ */
+   $Id: lz.cpp 10945 2012-08-22 08:03:45Z scranen $ */
 
 /* Bert Lisser: scratch buffer changed from fixed data array into reallocable
    array on the heap. Added function "int add2scratch(int last, char *c)" */
@@ -77,7 +77,8 @@ static void LZmakeToken(char c, unsigned int offset, unsigned int length, LZtoke
   if (length<=1)
   {
     token[0]=c;
-    token[1]='\0';
+    token[1]=0;
+    token[2]=0;
   }
   else
   {
