@@ -1,8 +1,10 @@
 #ifndef AFUN_H
 #define AFUN_H
 
+#include <assert.h>
 #include <string>
 #include <cstdio>
+#include <vector>
 #include "mcrl2/aterm/atypes.h"
 #include "mcrl2/aterm/encoding.h"
 
@@ -33,11 +35,9 @@ typedef struct _SymEntry
 static const size_t TERM_SIZE_SYMBOL = sizeof(struct _SymEntry)/sizeof(size_t);
 
 union _ATerm;
-extern union _ATerm** at_lookup_table_alias;
-extern SymEntry* at_lookup_table;
+extern std::vector < SymEntry > at_lookup_table;
 
-MachineWord AT_symbolTableSize();
-void AT_initAFun(int argc, char** argv);
+void AT_initAFun();
 size_t AT_printAFun(const AFun sym, FILE* f);
 
 inline
@@ -49,47 +49,35 @@ bool SYM_IS_FREE(const SymEntry sym)
 inline
 void AT_markAFun(const AFun s)
 {
-  at_lookup_table[s]->header |= MASK_AGE_MARK;
-}
-
-inline
-void AT_markAFun_young(const AFun s)
-{
-  if (!IS_OLD(at_lookup_table[s]->header))
-  {
-    AT_markAFun(s);
-  }
+  assert(s<at_lookup_table.size());
+  // at_lookup_table[s]->header |= MASK_AGE_MARK;
+  at_lookup_table[s]->header |= MASK_MARK;
 }
 
 inline
 void AT_unmarkAFun(const AFun s)
 {
+  assert(s<at_lookup_table.size());
   at_lookup_table[s]->header &= ~MASK_MARK;
 }
 
 inline
 bool AT_isValidAFun(const AFun sym)
 {
-  return (sym != (AFun)(-1) && (MachineWord)sym < AT_symbolTableSize()
-          && !SYM_IS_FREE(at_lookup_table[sym]));
-}
-
-// XXX Remove
-inline
-bool AT_isValidAFun(const ATerm sym)
-{
-  return AT_isValidAFun((AFun)sym);
+  return (sym != (AFun)(-1) && 
+          (MachineWord)sym < at_lookup_table.size() && 
+          !SYM_IS_FREE(at_lookup_table[sym]));
 }
 
 inline
 bool AT_isMarkedAFun(const AFun sym)
 {
+  assert(sym<at_lookup_table.size());
   return IS_MARKED(at_lookup_table[sym]->header);
 }
 
 void  AT_freeAFun(SymEntry sym);
 void AT_markProtectedAFuns();
-void AT_markProtectedAFuns_young();
 
 size_t AT_hashAFun(const char* name, const size_t arity);
 bool AT_findAFun(const char* name, const size_t arity, const bool quoted);
