@@ -4,6 +4,7 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <stdexcept>
+#include <set>
 #include "mcrl2/aterm/aterm2.h"
 #include "mcrl2/aterm/memory.h"
 #include "mcrl2/aterm/util.h"
@@ -26,24 +27,19 @@ ptrdiff_t SYM_GET_NEXT_FREE(const SymEntry sym)
 {
   return (ptrdiff_t)(sym) >> SHIFT_INDEX;
 }
-//#define SYM_GET_NEXT_FREE(sym)    ((ptrdiff_t)(sym) >> SHIFT_INDEX)
 
 inline
 size_t SYM_SET_NEXT_FREE(const AFun next)
 {
   return 1 | ((next) << SHIFT_INDEX);
 }
-//#define SYM_SET_NEXT_FREE(next)   (1 | ((next) << SHIFT_INDEX))
-
-static const size_t INITIAL_PROTECTED_SYMBOLS = 1024;
-static const size_t SYM_PROTECT_EXPAND_SIZE = 1024;
 
 static const size_t MAGIC_PRIME = 7;
 
 /*}}}  */
 /*{{{  globals */
 
-char afun_id[] = "$Id: afun.cpp 10238 2012-02-05 13:49:03Z jfg $";
+char afun_id[] = "$Id: afun.cpp 10487 2012-04-19 07:52:42Z jfg $";
 
 static size_t afun_table_class = INITIAL_AFUN_TABLE_CLASS;
 static MachineWord afun_table_size  = AT_TABLE_SIZE(INITIAL_AFUN_TABLE_CLASS);
@@ -51,15 +47,12 @@ static size_t afun_table_mask  = AT_TABLE_MASK(INITIAL_AFUN_TABLE_CLASS);
 
 static SymEntry* hash_table     = NULL;
 
-static AFun first_free = (size_t)(-1);
+static AFun first_free = (AFun)-1;
 
-static AFun* protected_symbols = NULL;
-static size_t nr_protected_symbols  = 0;
-static size_t max_protected_symbols  = 0;
+static std::multiset < AFun > protected_symbols;
 
-/* Efficiency hack: was static */
-SymEntry* at_lookup_table = NULL;
-ATerm*    at_lookup_table_alias = NULL;
+// SymEntry* at_lookup_table = NULL;
+std::vector < SymEntry > at_lookup_table;
 
 /*}}}  */
 
@@ -93,18 +86,6 @@ static void resize_table()
   MachineWord new_size  = AT_TABLE_SIZE(new_class);
   size_t new_mask  = AT_TABLE_MASK(new_class);
 
-  at_lookup_table = (SymEntry*)AT_realloc(at_lookup_table, new_size*sizeof(SymEntry));
-  at_lookup_table_alias = (ATerm*)at_lookup_table;
-  if (!at_lookup_table)
-  {
-    throw std::runtime_error("afun.c:resize_table - could not allocate space for lookup table of " + to_string(new_size) + " afuns");
-  }
-  for (i = afun_table_size; i < new_size; i++)
-  {
-    at_lookup_table[i] = (SymEntry) SYM_SET_NEXT_FREE(first_free);
-    first_free = i;
-  }
-
   hash_table = (SymEntry*)AT_realloc(hash_table, new_size*sizeof(SymEntry));
   if (!hash_table)
   {
@@ -112,7 +93,7 @@ static void resize_table()
   }
   memset(hash_table, 0, new_size*sizeof(SymEntry));
 
-  for (i=0; i<afun_table_size; i++)
+  for (i=0; i<at_lookup_table.size(); i++)
   {
     SymEntry entry = at_lookup_table[i];
     if (!SYM_IS_FREE(entry))
@@ -131,17 +112,8 @@ static void resize_table()
 
 /*}}}  */
 
-/*{{{  size_t AT_symbolTableSize() */
-
-MachineWord AT_symbolTableSize()
-{
-  return afun_table_size;
-}
-
-/*}}}  */
-
 /*{{{  void AT_initAFun(int argc, char *argv[]) */
-void AT_initAFun(int, char**)
+void AT_initAFun()
 {
   AFun sym;
 
@@ -151,26 +123,7 @@ void AT_initAFun(int, char**)
     throw std::runtime_error("AT_initAFun: cannot allocate " + to_string(afun_table_size) + " hash-entries.");
   }
 
-  at_lookup_table = (SymEntry*) AT_calloc(afun_table_size, sizeof(SymEntry));
-  at_lookup_table_alias = (ATerm*)at_lookup_table;
-  if (at_lookup_table == NULL)
-  {
-    throw std::runtime_error("AT_initAFun: cannot allocate " + to_string(afun_table_size) + " lookup-entries.");
-  }
-
-  first_free = 0;
-  for (sym = 0; sym < afun_table_size; sym++)
-  {
-    at_lookup_table[sym] = (SymEntry) SYM_SET_NEXT_FREE(sym+1);
-  }
-  at_lookup_table[afun_table_size-1] = (SymEntry) SYM_SET_NEXT_FREE((MachineWord)(-1));    /* Sentinel */
-
-  protected_symbols = (AFun*)AT_calloc(INITIAL_PROTECTED_SYMBOLS,
-                                       sizeof(AFun));
-  if (!protected_symbols)
-  {
-    throw std::runtime_error("AT_initAFun: cannot allocate initial protection buffer.");
-  }
+  first_free = AFun(-1); // Indication that there are no free AFun's available.
 
   sym = ATmakeAFun("<int>", 0, false);
   assert(sym == AS_INT);
@@ -210,6 +163,7 @@ void AT_initAFun(int, char**)
 
 size_t AT_printAFun(const AFun fun, FILE* f)
 {
+  assert(fun<at_lookup_table.size());
   SymEntry entry = at_lookup_table[fun];
   char* id = entry->name;
   size_t size = 0;
@@ -268,6 +222,7 @@ size_t AT_printAFun(const AFun fun, FILE* f)
 std::string ATwriteAFunToString(const AFun fun)
 {
   std::ostringstream oss;
+  assert(fun<at_lookup_table.size());
   SymEntry entry = at_lookup_table[fun];
   char* id = entry->name;
 
@@ -335,9 +290,8 @@ ShortHashNumber AT_hashAFun(const char* name, const size_t arity)
 
 AFun ATmakeAFun(const char* name, const size_t arity, const bool quoted)
 {
-  header_type header = SYMBOL_HEADER(arity, quoted);
-  ShortHashNumber hnr = AT_hashAFun(name, arity) & afun_table_mask;
-  SymEntry cur;
+  const header_type header = SYMBOL_HEADER(arity, quoted);
+  const ShortHashNumber hnr = AT_hashAFun(name, arity) & afun_table_mask;
 
   if (arity >= MAX_ARITY)
   {
@@ -345,7 +299,7 @@ AFun ATmakeAFun(const char* name, const size_t arity, const bool quoted)
   }
 
   /* Find symbol in table */
-  cur = hash_table[hnr];
+  SymEntry cur = hash_table[hnr];
   while (cur && (!EQUAL_HEADER(cur->header,header) || !streq(cur->name, name)))
   {
     cur = cur->next;
@@ -353,29 +307,31 @@ AFun ATmakeAFun(const char* name, const size_t arity, const bool quoted)
 
   if (cur == NULL)
   {
-    AFun free_entry;
+    cur = (SymEntry) AT_allocate(TERM_SIZE_SYMBOL); // Note that this statement changes first_free,
+                                                    // if garbage collection is done. 
 
-    free_entry = first_free;
-    if (free_entry == (AFun)(-1))
-    {
-      resize_table();
+    total_nodes--; // AT_allocate counts a function symbol as a node, but this is not correct, as it 
+                   // is not stored in the ATerm hashtable. This is to correct this.
+    const AFun free_entry = first_free;
+    assert(at_lookup_table.size()<afun_table_size);
+    assert(at_lookup_table.size()<afun_table_size); // There is a free places in the hash table.
 
-      /* Hashtable size changed, so recalculate hashnumber */
-      hnr = AT_hashAFun(name, arity) & afun_table_mask;
-
-      free_entry = first_free;
-      if (free_entry == (AFun)(-1))
-      {
-        throw std::runtime_error("AT_initAFun: out of symbol slots!");
-      }
+    if (free_entry!=(AFun)-1) // There is a free place in at_lookup_table to store an AFun.
+    { 
+      assert(first_free<at_lookup_table.size());
+      first_free = SYM_GET_NEXT_FREE(at_lookup_table[first_free]);
+      assert(first_free==(AFun)-1 || first_free<at_lookup_table.size());
+      assert(free_entry<at_lookup_table.size());
+      at_lookup_table[free_entry] = cur;
+      cur->id = free_entry;
+    }
+    else 
+    { 
+      cur->id = at_lookup_table.size();
+      at_lookup_table.push_back(cur);
     }
-    first_free = SYM_GET_NEXT_FREE(at_lookup_table[first_free]);
-
-    cur = (SymEntry) AT_allocate(TERM_SIZE_SYMBOL);
-    at_lookup_table[free_entry] = cur;
 
     cur->header = header;
-    cur->id = free_entry;
     cur->count = 0;
     cur->index = -1;
 
@@ -389,6 +345,10 @@ AFun ATmakeAFun(const char* name, const size_t arity, const bool quoted)
     hash_table[hnr] = cur;
   }
 
+  if (at_lookup_table.size()>=afun_table_size*0.7) // Resize when more than 70% of the spots in the hash table are filled.
+  {
+    resize_table();
+  }
   return cur->id;
 }
 
@@ -401,15 +361,11 @@ AFun ATmakeAFun(const char* name, const size_t arity, const bool quoted)
 
 void AT_freeAFun(SymEntry sym)
 {
-  ShortHashNumber hnr;
-
-  terminfo[TERM_SIZE_SYMBOL].nb_reclaimed_cells_during_last_gc++;
-
+  /* The code of this function resembles that of AT_freeTerm very much */
   assert(sym->name);
 
   /* Calculate hashnumber */
-  hnr = AT_hashAFun(sym->name, GET_LENGTH(sym->header));
-  hnr &= afun_table_mask;
+  const ShortHashNumber hnr = AT_hashAFun(sym->name, GET_LENGTH(sym->header)) & afun_table_mask;
 
   /* Update hashtable */
   if (hash_table[hnr] == sym)
@@ -431,8 +387,10 @@ void AT_freeAFun(SymEntry sym)
   AT_free(sym->name);
   sym->name = NULL;
 
+  assert(sym->id<at_lookup_table.size());
   at_lookup_table[sym->id] = (SymEntry)SYM_SET_NEXT_FREE(first_free);
   first_free = sym->id;
+  assert(first_free==(AFun)-1 || first_free<at_lookup_table.size());
 }
 
 /*}}}  */
@@ -445,19 +403,7 @@ void AT_freeAFun(SymEntry sym)
 
 void ATprotectAFun(const AFun sym)
 {
-
-  if (nr_protected_symbols >= max_protected_symbols)
-  {
-    max_protected_symbols += SYM_PROTECT_EXPAND_SIZE;
-    protected_symbols = (AFun*)AT_realloc(protected_symbols,
-                                          max_protected_symbols * sizeof(AFun));
-    if (!protected_symbols)
-    {
-      throw std::runtime_error("ATprotectAFun: no space to hold " + to_string(max_protected_symbols) + " protected symbols.");
-    }
-  }
-
-  protected_symbols[nr_protected_symbols++] = sym;
+  protected_symbols.insert(sym);
 }
 
 /*}}}  */
@@ -469,25 +415,13 @@ void ATprotectAFun(const AFun sym)
 
 void ATunprotectAFun(const AFun sym)
 {
-  /* It is essential for performance that in this file
-   * the protected_symbols array is traversed from back
-   * to front. This function is only invoked by
-   * ATdestroyBinaryReader, which stacks symbols at the
-   * end of protected symbols, and removes them in
-   * reverse order. */
-
-  size_t lcv;
-
-  for (lcv = nr_protected_symbols; lcv >0 ;)
+  // Remove only one occurrence of sym: erase cannot be used.
+  const std::multiset < AFun >::const_iterator i=protected_symbols.find(sym);
+  if (i!=protected_symbols.end())
   {
-    --lcv;
-    if (protected_symbols[lcv] == sym)
-    {
-      protected_symbols[lcv] = protected_symbols[--nr_protected_symbols];
-      protected_symbols[nr_protected_symbols] = (AFun)-1; // Reset
-      break;
-    }
+    protected_symbols.erase(i);
   }
+  else assert(0); // A non protected symbol is being unprotected.
 }
 
 /*}}}  */
@@ -499,24 +433,10 @@ void ATunprotectAFun(const AFun sym)
 
 void AT_markProtectedAFuns()
 {
-  size_t lcv;
-  for (lcv = 0; lcv < nr_protected_symbols; lcv++)
+  for(std::multiset < AFun >::const_iterator i=protected_symbols.begin(); i!=protected_symbols.end(); ++i)
   {
-    SET_MARK(((ATerm)at_lookup_table[protected_symbols[lcv]])->header);
-  }
-}
-
-/* TODO: Optimisation (Old+Mark in one step)*/
-void AT_markProtectedAFuns_young()
-{
-  size_t lcv;
-
-  for (lcv = 0; lcv < nr_protected_symbols; lcv++)
-  {
-    if (!IS_OLD(((ATerm)at_lookup_table[protected_symbols[lcv]])->header))
-    {
-      SET_MARK(((ATerm)at_lookup_table[protected_symbols[lcv]])->header);
-    }
+    assert(at_lookup_table.size()> *i);
+    SET_MARK(((ATerm)at_lookup_table[*i])->header);
   }
 }
 
