@@ -109,7 +109,7 @@ typedef struct
 /*}}}  */
 /*{{{  variables */
 
-char bafio_id[] = "$Id: bafio.cpp 10015 2011-12-14 12:15:29Z jkeiren $";
+char bafio_id[] = "$Id: bafio.cpp 10771 2012-07-03 19:34:13Z jkeiren $";
 
 static size_t nr_unique_symbols = 0;
 static sym_read_entry* read_symbols;
@@ -124,21 +124,6 @@ static size_t  bits_in_buffer = 0; /* how many bits in bit_buffer are used */
 
 /*}}}  */
 
-/*{{{  void AT_initBafIO(int argc, char *argv[]) */
-
-/**
-  * Initialize BafIO code.
-  */
-
-void AT_initBafIO(int argc, char* argv[])
-{
-  /* Suppress unused arguments warning */
-  (void) argc;
-  (void) argv;
-}
-
-/*}}}  */
-
 /*{{{  void AT_getBafVersion(int *major, int *minor) */
 
 void
@@ -976,7 +961,7 @@ static bool
 write_baf(const ATerm t, byte_writer* writer)
 {
   size_t nr_unique_terms = 0;
-  size_t nr_symbols = AT_symbolTableSize();
+  size_t nr_symbols = at_lookup_table.size();
   AFun lcv;
   size_t cur;
 
@@ -1202,9 +1187,9 @@ bool ATwriteToNamedBinaryFile(ATerm t, const char* name)
 static AFun read_symbol(byte_reader* reader)
 {
   size_t arity, quoted;
-  size_t len;
+  size_t len = readString(reader);
 
-  if ((len = readString(reader)) == ATERM_NON_EXISTING_POSITION)
+  if (len == ATERM_NON_EXISTING_POSITION)
   {
     return ATERM_NON_EXISTING_POSITION;
   }
