@@ -15,23 +15,15 @@
 #include <boost/utility/enable_if.hpp>
 #include <boost/type_traits/is_base_of.hpp>
 
-#include "aterm2.h"
+#include <utility>
+#include "mcrl2/aterm/aterm2.h"
+
+// XXX Remove
+using namespace aterm;
 
 namespace atermpp
 {
 
-inline
-void aterm_protect(const ATerm* x)
-{
-	ATprotect(const_cast<ATerm*>(x));
-}
-
-inline
-void aterm_unprotect(const ATerm* x)
-{
-	ATunprotect(const_cast<ATerm*>(x));
-}
-
 class aterm;
 
 template < typename T >
@@ -76,13 +68,13 @@ struct aterm_traits<ATerm>
 {
   static void protect(const ATerm* t)
   {
-    aterm_protect(t);
+    ATprotect(t);
   }
   static void unprotect(const ATerm* t)
   {
-    aterm_unprotect(t);
+    ATunprotect(t);
   }
-  static void mark(ATerm t)
+  static void mark(const ATerm t)
   {
     ATmarkTerm(t);
   }
@@ -154,6 +146,26 @@ struct aterm_traits<ATermInt>
     return reinterpret_cast<ATerm>(t);
   }
 };
+
+template<typename T1, typename T2>
+struct aterm_traits<std::pair<T1, T2> >
+{
+  static void protect(const std::pair<T1, T2>& t)
+  {
+    aterm_traits<T1>::protect(t.first);
+    aterm_traits<T2>::protect(t.second);
+  }
+  static void unprotect(const std::pair<T1, T2>& t)
+  {
+    aterm_traits<T1>::unprotect(t.first);
+    aterm_traits<T2>::unprotect(t.second);
+  }
+  static void mark(const std::pair<T1, T2>& t)
+  {
+    aterm_traits<T1>::mark(t.first);
+    aterm_traits<T2>::mark(t.second);
+  }
+};
 /// \endcond
 
 } // namespace atermpp
