@@ -26,7 +26,7 @@ int test_main(int argc, char* argv[])
   MCRL2_ATERMPP_INIT(argc, argv)
   // unquoted function symbol s == "f"
   function_symbol s("\"f\"", 1, false);
-  aterm x=aterm_appl(function_symbol("x",0));
+  atermpp::aterm x=aterm_appl(function_symbol("x",0));
   aterm_appl f(s, x);
 
   // convert to string and back
