@@ -18,7 +18,6 @@
 #include <iterator>
 #include <sstream>
 #include <string>
-#include <boost/foreach.hpp>
 #include "mcrl2/atermpp/aterm_appl.h"
 #include "mcrl2/atermpp/vector.h"
 #include "mcrl2/core/detail/constructors.h"
@@ -26,7 +25,7 @@
 #include "mcrl2/core/detail/soundness_checks.h"
 #include "mcrl2/core/detail/aterm_io.h"
 #include "mcrl2/core/term_traits.h"
-#include "mcrl2/exception.h"
+#include "mcrl2/utilities/exception.h"
 #include "mcrl2/bes/boolean_equation.h"
 
 namespace mcrl2
@@ -63,9 +62,13 @@ class boolean_equation_system
     void init_term(atermpp::aterm_appl t)
     {
       atermpp::aterm_appl::iterator i = t.begin();
-      boolean_equation_list eqn = *i++;
+      atermpp::aterm_list eqn = *i++;
       m_initial_state = boolean_expression(*i);
-      m_equations = Container(eqn.begin(), eqn.end());
+      m_equations.reserve(eqn.size());
+      for (atermpp::aterm_list::iterator j = eqn.begin(); j != eqn.end(); ++j)
+      {
+        m_equations.push_back(boolean_equation(*j));
+      }
     }
 
   public:
@@ -159,7 +162,7 @@ class boolean_equation_system
     /// \return An ATerm representation of the boolean equation system
     operator ATermAppl() const
     {
-      boolean_equation_list equations(m_equations.begin(), m_equations.end());
+      atermpp::aterm_list equations(m_equations.begin(), m_equations.end());
       return core::detail::gsMakeBES(equations, m_initial_state);
     }
 
