@@ -501,7 +501,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term has the value true
   static inline
-  bool is_true(term_type t)
+  bool is_true(const term_type& t)
   {
     return core::detail::gsIsBooleanTrue(t);
   }
@@ -510,7 +510,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term has the value false
   static inline
-  bool is_false(term_type t)
+  bool is_false(const term_type& t)
   {
     return core::detail::gsIsBooleanFalse(t);
   }
@@ -519,7 +519,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term is of type and
   static inline
-  bool is_not(term_type t)
+  bool is_not(const term_type& t)
   {
     return core::detail::gsIsBooleanNot(t);
   }
@@ -528,7 +528,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term is of type and
   static inline
-  bool is_and(term_type t)
+  bool is_and(const term_type& t)
   {
     return core::detail::gsIsBooleanAnd(t);
   }
@@ -537,7 +537,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term is of type or
   static inline
-  bool is_or(term_type t)
+  bool is_or(const term_type& t)
   {
     return core::detail::gsIsBooleanOr(t);
   }
@@ -546,7 +546,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term is an implication
   static inline
-  bool is_imp(term_type t)
+  bool is_imp(const term_type& t)
   {
     return core::detail::gsIsBooleanImp(t);
   }
@@ -555,7 +555,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term is a boolean variable
   static inline
-  bool is_variable(term_type t)
+  bool is_variable(const term_type& t)
   {
     return core::detail::gsIsBooleanVariable(t);
   }
@@ -564,7 +564,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return True if the term is a propositional variable
   static inline
-  bool is_prop_var(term_type t)
+  bool is_prop_var(const term_type& t)
   {
     return is_variable(t);
   }
@@ -573,7 +573,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return The requested argument
   static inline
-  term_type arg(term_type t)
+  term_type arg(const term_type& t)
   {
     assert(is_not(t));
     return atermpp::arg1(t);
@@ -583,7 +583,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return The left argument of the term
   static inline
-  term_type left(term_type t)
+  term_type left(const term_type& t)
   {
     assert(is_and(t) || is_or(t) || is_imp(t));
     return atermpp::arg1(t);
@@ -593,17 +593,26 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return The right argument of the term
   static inline
-  term_type right(term_type t)
+  term_type right(const term_type& t)
   {
     assert(is_and(t) || is_or(t) || is_imp(t));
     return atermpp::arg2(t);
   }
 
+  /// \brief Returns the argument of a term of type not
+  /// \param t A term
+  static inline
+  term_type not_arg(const term_type& t)
+  {
+    assert(is_not(t));
+    return atermpp::arg1(t);
+  }
+
   /// \brief Returns the name of a boolean variable
   /// \param t A term
   /// \return The name of the boolean variable
   static inline
-  string_type name(term_type t)
+  string_type name(const term_type& t)
   {
     assert(is_variable(t));
     return atermpp::arg1(t);
@@ -622,7 +631,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t a term
   /// \returns The converted term
   static inline
-  variable_type term2variable(term_type t)
+  variable_type term2variable(const term_type& t)
   {
     return t;
   }
@@ -631,7 +640,7 @@ struct term_traits<bes::boolean_expression>
   /// \param t A term
   /// \return Returns a pretty print representation of the term
   static inline
-  std::string pp(term_type t)
+  std::string pp(const term_type& t)
   {
     return bes::pp(t);
   }
