@@ -1971,7 +1971,6 @@ ATermAppl gsMakeActionRenameSpec(ATermAppl DataSpec_0, ATermAppl ActSpec_1, ATer
 inline
 ATermAppl gsMakeAllow(ATermList MultActName_0, ATermAppl ProcExpr_1)
 {
-  assert(!ATisEmpty(MultActName_0));
   return ATmakeAppl2(function_symbol_Allow(), (ATerm) MultActName_0, (ATerm) ProcExpr_1);
 }
 
@@ -2886,12 +2885,6 @@ bool gsIsFixpoint(ATermAppl Term)
   return gsIsMu(Term) || gsIsNu(Term);
 }
 
-///\pre MultAct is a multiaction
-///\return the sorted variant of the argument
-/// TODO: Should be moved to process or lps library
-ATermAppl gsSortMultAct(ATermAppl MultAct);
-
-
 }
 }
 }
