@@ -1,4 +1,4 @@
-// Author(s): Aad Mathijssen
+// Author(s): Wieger Wesselink
 // Copyright: see the accompanying file COPYING or copy at
 // https://svn.win.tue.nl/trac/MCRL2/browser/trunk/COPYING
 //
@@ -21,13 +21,15 @@
 #include "mcrl2/atermpp/aterm_list.h"
 #include "mcrl2/atermpp/vector.h"
 #include "mcrl2/core/identifier_string.h"
-#include "mcrl2/exception.h"
+#include "mcrl2/utilities/exception.h"
 #include "mcrl2/core/dparser.h"
 #include "mcrl2/core/detail/dparser_functions.h"
 
 extern "C"
 {
   extern D_ParserTables parser_tables_mcrl2;
+  extern D_ParserTables parser_tables_fsm;
+  extern D_ParserTables parser_tables_dot;
 }
 
 namespace mcrl2
@@ -35,11 +37,11 @@ namespace mcrl2
 namespace core
 {
 
-struct default_parser_actions
+struct parser_actions
 {
   const parser_table& table;
 
-  default_parser_actions(const parser_table& table_)
+  parser_actions(const parser_table& table_)
     : table(table_)
   {}
 
@@ -60,6 +62,37 @@ struct default_parser_actions
     }
   }
 
+  // callback function that applies a function to nodes of a given type
+  template <typename Function>
+  struct visitor
+  {
+    const parser_table& table;
+    const std::string& type;
+    Function f;
+
+    visitor(const parser_table& table_, const std::string& type_, Function f_)
+      : table(table_),
+        type(type_),
+        f(f_)
+    {}
+
+    bool operator()(const parse_node& node) const
+    {
+      if (table.symbol_name(node) == type)
+      {
+        f(node);
+        return true;
+      }
+      return false;
+    }
+  };
+
+  template <typename Function>
+  visitor<Function> make_visitor(const parser_table& table, const std::string& type, Function f)
+  {
+    return visitor<Function>(table, type, f);
+  }
+
   // callback function that applies a function to a node, and adds the result to a container
   template <typename Container, typename Function>
   struct collector
@@ -93,6 +126,39 @@ struct default_parser_actions
     return collector<Container, Function>(table, type, container, f);
   }
 
+  // callback function that applies a function to a node, and adds the result to a set container
+  template <typename SetContainer, typename Function>
+  struct set_collector
+  {
+    const parser_table& table;
+    const std::string& type;
+    SetContainer& container;
+    Function f;
+
+    set_collector(const parser_table& table_, const std::string& type_, SetContainer& container_, Function f_)
+      : table(table_),
+        type(type_),
+        container(container_),
+        f(f_)
+    {}
+
+    bool operator()(const parse_node& node) const
+    {
+      if (table.symbol_name(node) == type)
+      {
+        container.insert(f(node));
+        return true;
+      }
+      return false;
+    }
+  };
+
+  template <typename SetContainer, typename Function>
+  set_collector<SetContainer, Function> make_set_collector(const parser_table& table, const std::string& type, SetContainer& container, Function f)
+  {
+    return set_collector<SetContainer, Function>(table, type, container, f);
+  }
+
   std::string symbol_name(const parse_node& node) const
   {
     return table.symbol_name(node.symbol());
@@ -116,6 +182,13 @@ struct default_parser_actions
     std::cout << "--- unexpected node ---\n" << print_node(node);
     throw mcrl2::runtime_error("unexpected node detected!");
   }
+};
+
+struct default_parser_actions: public parser_actions
+{
+  default_parser_actions(const parser_table& table_)
+    : parser_actions(table_)
+  {}
 
   template <typename T, typename Function>
   atermpp::term_list<T> parse_list(const parse_node& node, const std::string& type, Function f)
