@@ -17,9 +17,6 @@ int main(int argc, char* argv[])
                                    "map                       \n"
                                    "  invert: Bit -> Bit;     \n"
                                    "                          \n"
-                                   "cons                      \n"
-                                   "  K: Pos;                 \n"
-                                   "                          \n"
                                    "eqn                       \n"
                                    "  invert(b1)= b0;         \n"
                                    "  invert(b0)= b1;         \n"
