@@ -16,6 +16,13 @@
 #include "mcrl2/data/bool.h"
 #include "mcrl2/data/standard.h"
 
+namespace mcrl2
+{
+namespace data
+{
+namespace detail
+{
+
 /// \brief The class BDD_Info provides information about the structure of binary decision diagrams.
 class BDD_Info
 {
@@ -25,53 +32,57 @@ class BDD_Info
     /// \brief Method that returns the guard of a BDD.
     /// \param[in] a_bdd A binary decision diagram.
     /// \return The guard at the root of the BDD.
-    inline ATermAppl get_guard(ATermAppl a_bdd)
+    inline mcrl2::data::data_expression get_guard(const mcrl2::data::data_expression a_bdd)
     {
-      return ATAgetFirst(ATLgetArgument(a_bdd, 1));
+      return application(a_bdd).argument(0);
     }
 
     /// \brief Method that returns the true-branch of a BDD.
     /// \param[in] a_bdd A binary decision diagram.
     /// \return The true-branch of the BDD.
-    inline ATermAppl get_true_branch(ATermAppl a_bdd)
+    inline mcrl2::data::data_expression get_true_branch(const mcrl2::data::data_expression  a_bdd)
     {
-      return ATAgetFirst(ATgetNext(ATLgetArgument(a_bdd, 1)));
+      return application(a_bdd).argument(1);  
     }
 
     /// \brief Method that returns the false-branch of a BDD.
     /// \param[in] a_bdd A binary decision diagram.
     /// \return The false-branch of the BDD.
-    inline ATermAppl get_false_branch(ATermAppl a_bdd)
+    inline mcrl2::data::data_expression get_false_branch(const mcrl2::data::data_expression a_bdd)
     {
-      return ATAgetFirst(ATgetNext(ATgetNext(ATLgetArgument(a_bdd, 1))));
+      return application(a_bdd).argument(2);
     }
 
     /// \brief Method that indicates whether or not a BDD equals true.
     /// \param[in] a_bdd A binary decision diagram.
     /// \return True, if the BDD equals true.
     ///         False, if the BDD does not equal true.
-    inline bool is_true(ATermAppl a_bdd)
+    inline bool is_true(const data_expression a_bdd)
     {
-      return mcrl2::data::sort_bool::is_true_function_symbol(mcrl2::data::data_expression(a_bdd));
+      return mcrl2::data::sort_bool::is_true_function_symbol(a_bdd);
     }
 
     /// \brief Method that indicates whether or not a BDD equals false.
     /// \param[in] a_bdd A binary decision diagram.
     /// \return True, if the BDD equals false.
     ///         False, if the BDD does not equal true.
-    inline bool is_false(ATermAppl a_bdd)
+    inline bool is_false(const data_expression a_bdd)
     {
-      return mcrl2::data::sort_bool::is_false_function_symbol(mcrl2::data::data_expression(a_bdd));
+      return mcrl2::data::sort_bool::is_false_function_symbol(a_bdd);
     }
 
     /// \brief Method that indicates wether or not the root of a BDD is a guard node.
     /// \param[in] a_bdd A binary decision diagram.
     /// \return True, if the root of the BDD is a guard node.
     ///         False, if the BDD equals true or if the BDD equals false.
-    inline bool is_if_then_else(ATermAppl a_bdd)
+    inline bool is_if_then_else(const data_expression a_bdd)
     {
-      return mcrl2::data::is_if_application(mcrl2::data::data_expression(a_bdd));
+      return mcrl2::data::is_if_application(a_bdd);
     }
 };
 
+}
+}
+}
+
 #endif
