@@ -13,6 +13,7 @@
 #define SMT_SOLVER_H
 
 #include "mcrl2/aterm/aterm2.h"
+#include "mcrl2/data/data_expression.h"
 
 namespace mcrl2
 {
@@ -21,14 +22,11 @@ namespace data
 namespace detail
 {
 
-// XXX remove
-using namespace aterm;
-
 class SMT_Solver
 {
   public:
     virtual ~SMT_Solver() {};
-    virtual bool is_satisfiable(ATermList a_formula) = 0;
+    virtual bool is_satisfiable(const data_expression_list a_formula) = 0;
 };
 }
 }
