@@ -19,7 +19,7 @@
 #include <fstream>
 #include "mcrl2/aterm/aterm2.h"
 #include "boost/algorithm/string.hpp"
-#include "mcrl2/exception.h"
+#include "mcrl2/utilities/exception.h"
 #include "mcrl2/atermpp/aterm_appl.h"
 #include "mcrl2/atermpp/vector.h"
 #include "mcrl2/atermpp/table.h"
@@ -46,6 +46,14 @@ struct sort_expression_actions: public core::default_parser_actions
   {}
 
   data::sort_expression parse_SortExpr(const core::parse_node& node)
+  {
+    if ((node.child_count() == 1) && (symbol_name(node.child(0)) == "SimpleSortExpr")) { return parse_SimpleSortExpr(node.child(0)); }
+    else if ((node.child_count() == 1) && (symbol_name(node.child(0)) == "ComplexSortExpr")) { return parse_ComplexSortExpr(node.child(0)); }
+    report_unexpected_node(node);
+    return data::sort_expression();
+  }
+
+  data::sort_expression parse_SimpleSortExpr(const core::parse_node& node)
   {
     if ((node.child_count() == 1) && (symbol_name(node.child(0)) == "Bool")) { return sort_bool::bool_(); }
     else if ((node.child_count() == 1) && (symbol_name(node.child(0)) == "Pos")) { return sort_pos::pos(); }
@@ -57,12 +65,16 @@ struct sort_expression_actions: public core::default_parser_actions
     else if ((node.child_count() == 4) && (symbol_name(node.child(0)) == "Bag") && (symbol_name(node.child(1)) == "(") && (symbol_name(node.child(2)) == "SortExpr") && (symbol_name(node.child(3)) == ")")) { return sort_bag::bag(parse_SortExpr(node.child(2))); }
     else if ((node.child_count() == 1) && (symbol_name(node.child(0)) == "Id")) { return basic_sort(parse_Id(node.child(0))); }
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "(") && (symbol_name(node.child(1)) == "SortExpr") && (symbol_name(node.child(2)) == ")")) { return parse_SortExpr(node.child(1)); }
-    else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "SortExprList") && (node.child(1).string() == "->") && (symbol_name(node.child(2)) == "SortExpr")) { return function_sort(parse_SortExprList(node.child(0)), parse_SortExpr(node.child(2))); }
     else if ((node.child_count() == 2) && (symbol_name(node.child(0)) == "struct") && (symbol_name(node.child(1)) == "ConstrDeclList")) { return structured_sort(parse_ConstrDeclList(node.child(1))); }
     report_unexpected_node(node);
     return data::sort_expression();
   }
 
+  data::sort_expression parse_ComplexSortExpr(const core::parse_node& node)
+  {
+    return function_sort(parse_SortExprList(node.child(0)), parse_SortExpr(node.child(2)));
+  }
+
   data::sort_expression_list parse_SortExprList(const core::parse_node& node)
   {
     return parse_list<data::sort_expression>(node, "SortExpr", boost::bind(&sort_expression_actions::parse_SortExpr, this, _1));
