@@ -16,7 +16,7 @@
 #include <functional>
 
 #include "mcrl2/data/data_specification.h"
-#include "mcrl2/exception.h"
+#include "mcrl2/utilities/exception.h"
 
 namespace mcrl2
 {
