@@ -24,6 +24,9 @@
 #include "mcrl2/data/assignment.h"
 #include "mcrl2/data/data_specification.h"
 #include "mcrl2/data/multiple_possible_sorts.h"
+#include "mcrl2/data/exists.h"
+#include "mcrl2/data/forall.h"
+#include "mcrl2/data/lambda.h"
 #include "mcrl2/data/unknown_sort.h"
 
 namespace mcrl2
