@@ -76,6 +76,16 @@ typedef atermpp::vector<variable>    variable_vector;
 
 //--- end generated class variable ---//
 
+// template function overloads
+std::string pp(const variable& x);
+std::string pp(const variable_list& x);
+std::string pp(const variable_vector& x);
+std::string pp(const std::set<variable>& x);
+std::string pp(const atermpp::set<variable>& x);
+std::set<data::variable> find_variables(const data::variable& x);
+std::set<data::variable> find_variables(const data::variable_list& x);
+std::set<core::identifier_string> find_identifiers(const data::variable_list& x);
+
 /// \brief Converts an container with variables to a variable_list
 /// \param r A range of variables.
 /// \note This function uses implementation details of the iterator type
