@@ -399,6 +399,8 @@ bool EnumeratorSolutionsStandard::next(
               atermpp::term_list<atermpp::aterm_appl> &solution,
               bool &solution_possible)
 {
+  vector < atermpp::aterm > var_array; // This does not need to be a atermpp vector, as its content
+                                       // is protected elsewhere.
   while (ss_stack.empty() && !fs_stack.empty())
   {
     fs_expr e=fs_stack.front();
@@ -423,6 +425,7 @@ bool EnumeratorSolutionsStandard::next(
       const sort_expression sort = var.sort();
       variable_list uvars = pop_front(e.vars());
 
+
       if (is_function_sort(sort))
       {
         if (solution_possible)
@@ -508,22 +511,22 @@ bool EnumeratorSolutionsStandard::next(
           assert(target_sort==sort);
 
           variable_list var_list;
-          MCRL2_SYSTEM_SPECIFIC_ALLOCA(var_array,atermpp::aterm,domain_sorts.size()+1);
-          size_t j=1;
-          var_array[0]=OpId2Int(*it);
-          for (sort_expression_list::const_iterator i=domain_sorts.begin(); i!=domain_sorts.end(); ++i,++j)
+          assert(var_array.size()==0);
+          var_array.push_back(OpId2Int(*it));
+          
+          for (sort_expression_list::const_iterator i=domain_sorts.begin(); i!=domain_sorts.end(); ++i)
           {
             const variable fv(m_enclosing_enumerator->rewr_obj->generator("@x@",false),*i);
             var_list = push_front(var_list,fv);
-            var_array[j]=fv;
-
+            var_array.push_back(fv);
 
             used_vars++;
             if (m_max_internal_variables!=0 && used_vars > m_max_internal_variables)
             {
-              if (solution_possible)
+              if (solution_possible && max_vars != 0)
               {
-                mCRL2log(log::warning) << "Terminated enumeration of variables because more than " << m_max_internal_variables << " are used\n";
+                mCRL2log(log::debug)   << "Enumerating expression: "<< data::pp(m_enclosing_enumerator->rewr_obj->fromRewriteFormat(enum_expr)) << std::endl;
+                mCRL2log(log::warning) << "Terminated enumeration of variables because more than " << m_max_internal_variables << " are used.\n";
                 solution_possible=false;
                 return false;
               }
@@ -546,7 +549,7 @@ bool EnumeratorSolutionsStandard::next(
             }
             else if (used_vars > max_vars)
             {
-              cerr << "need more than " << max_vars << " variables to find all valuations of ";
+              mCRL2log(log::info) << "need more than " << max_vars << " variables to find all valuations of ";
               for (variable_list::const_iterator k=enum_vars.begin(); k!=enum_vars.end(); ++k)
               {
                 if (k != enum_vars.begin())
@@ -562,7 +565,8 @@ bool EnumeratorSolutionsStandard::next(
           // Substitutions must contain normal forms.  term_rf is almost always a normal form, but this is
           // not guaranteed and must be guaranteed by rewriting it explicitly. In the line below enum_sigma has no effect, but
           // using it is much cheaper than using a default substitution.
-          const atermpp::aterm_appl term_rf = m_enclosing_enumerator->rewr_obj->rewrite_internal(ApplyArray(domain_sorts.size()+1,var_array),enum_sigma);
+          const atermpp::aterm_appl term_rf = m_enclosing_enumerator->rewr_obj->rewrite_internal(ApplyArray(domain_sorts.size()+1,&var_array[0]),enum_sigma);
+          var_array.clear();
 
           const atermpp::aterm_appl old_substituted_value=enum_sigma(var);
           enum_sigma[var]=term_rf;
@@ -616,15 +620,28 @@ bool EnumeratorSolutionsStandard::next(
   return next(dummy_evaluated_condition,solution,solution_possible);
 }
 
-void EnumeratorSolutionsStandard::reset(const bool not_equal_to_false)
+void EnumeratorSolutionsStandard::reset(const bool not_equal_to_false,const bool expr_is_normal_form)
 {
-  push_on_fs_stack_and_split_or(fs_stack,
-                                enum_vars,
-                                variable_list(),
-                                atermpp::term_list< atermpp::aterm_appl>(),
-                                enum_expr,
-                                atermpp::term_list< atermpp::aterm_appl>(),
-                                !not_equal_to_false);
+  if (expr_is_normal_form)
+  {
+    push_on_fs_stack_and_split_or_without_rewriting(fs_stack,
+                                  enum_vars,
+                                  variable_list(),
+                                  atermpp::term_list< atermpp::aterm_appl>(),
+                                  enum_expr,
+                                  atermpp::term_list< atermpp::aterm_appl>(),
+                                  !not_equal_to_false);
+  }
+  else
+  {
+    push_on_fs_stack_and_split_or(fs_stack,
+                                  enum_vars,
+                                  variable_list(),
+                                  atermpp::term_list< atermpp::aterm_appl>(),
+                                  enum_expr,
+                                  atermpp::term_list< atermpp::aterm_appl>(),
+                                  !not_equal_to_false);
+  }
 }
 
 EnumeratorStandard::EnumeratorStandard(const mcrl2::data::data_specification &data_spec, Rewriter* r):
