@@ -23,7 +23,7 @@
 #include "boost/config.hpp"
 
 #include "mcrl2/utilities/detail/memory_utility.h"
-#include "mcrl2/exception.h"
+#include "mcrl2/utilities/exception.h"
 #include "mcrl2/aterm/aterm2.h"
 #include "mcrl2/aterm/aterm_ext.h"
 #include "mcrl2/atermpp/aterm_access.h"
@@ -69,15 +69,12 @@ static function_symbol get_function_symbol_of_head(const data_expression t)
   return get_function_symbol_of_head(application(t).head());
 }
 
-
-
-static ATermList create_strategy(data_equation_list rules1, RewriterJitty *rewriter)
+ATermList RewriterJitty::create_strategy(data_equation_list rules1) //, RewriterJitty *rewriter)
 {
-
   size_t max_arity = 0;
-  for (data_equation_list::const_iterator l=rules1.begin(); l!=rules1.end(); ++l) 
+  for (data_equation_list::const_iterator l=rules1.begin(); l!=rules1.end(); ++l)
   {
-    const size_t current_arity=rewriter->toRewriteFormat(l->lhs()).size();
+    const size_t current_arity=toRewriteFormat(l->lhs()).size();
     if (current_arity > max_arity + 1)
     {
       max_arity = current_arity-1;
@@ -87,11 +84,11 @@ static ATermList create_strategy(data_equation_list rules1, RewriterJitty *rewri
 
   ATermList rules=ATempty;
   for(data_equation_list::const_iterator j=rules1.begin(); j!=rules1.end(); ++j)
-  { 
+  {
     rules = ATinsert(rules,(ATerm) ATmakeList4((ATerm) static_cast<ATermList>(j->variables()),
-                                         (ATerm)(ATermAppl)rewriter->toRewriteFormat(j->condition()),
-                                         (ATerm) (ATermAppl)rewriter->toRewriteFormat(j->lhs()),
-                                         (ATerm)(ATermAppl)rewriter->toRewriteFormat(j->rhs()))); 
+                                         (ATerm)(ATermAppl)toRewriteFormat(j->condition()),
+                                         (ATerm) (ATermAppl)toRewriteFormat(j->lhs()),
+                                         (ATerm)(ATermAppl)toRewriteFormat(j->rhs())));
   }
   rules = ATreverse(rules);
 
@@ -202,7 +199,13 @@ static ATermList create_strategy(data_equation_list rules1, RewriterJitty *rewri
       {
         if (ATisEmpty(ATLgetFirst(ATLgetFirst(m))))
         {
-          strat = ATinsert(strat, ATgetFirst(ATgetNext(ATLgetFirst(m))));
+          ATerm rule=ATgetFirst(ATgetNext(ATLgetFirst(m)));
+          strat = ATinsert(strat, rule);
+          size_t len =ATgetLength(ATLgetFirst((ATermList)rule));
+          if (len>MAX_LEN) 
+          {
+            MAX_LEN=len;
+          }
         }
         else
         {
@@ -266,12 +269,13 @@ void RewriterJitty::make_jitty_strat_sufficiently_larger(const size_t i)
 }
 
 RewriterJitty::RewriterJitty(
-           const data_specification& data_spec, 
+           const data_specification& data_spec,
            const mcrl2::data::used_data_equation_selector& equation_selector):
         Rewriter()
 {
   m_data_specification_for_enumeration = data_spec;
 
+  MAX_LEN=0;
   max_vars = 0;
   need_rebuild = false;
 
@@ -322,7 +326,7 @@ RewriterJitty::RewriterJitty(
     }
     else
     {
-      jitty_strat[i.value()] = create_strategy(reverse(it->second), this);
+      jitty_strat[i.value()] = create_strategy(reverse(it->second));
     }
   }
 }
@@ -679,6 +683,9 @@ atermpp::aterm_appl RewriterJitty::rewrite_aux_function_symbol(
   make_jitty_strat_sufficiently_larger(op.value());
   if ((strat = jitty_strat[op.value()]) != NULL)
   {
+    MCRL2_SYSTEM_SPECIFIC_ALLOCA(vars,variable, MAX_LEN);
+    MCRL2_SYSTEM_SPECIFIC_ALLOCA(vals,atermpp::aterm, MAX_LEN);
+
     for (; !ATisEmpty(strat); strat=ATgetNext(strat))
     {
       if (ATisInt(ATgetFirst(strat)))
@@ -705,9 +712,10 @@ atermpp::aterm_appl RewriterJitty::rewrite_aux_function_symbol(
         }
 
         size_t max_len = ATgetLength(ATLgetFirst(rule));
+        assert(max_len<=MAX_LEN);
 
-        MCRL2_SYSTEM_SPECIFIC_ALLOCA(vars,variable, max_len);
-        MCRL2_SYSTEM_SPECIFIC_ALLOCA(vals,atermpp::aterm, max_len);
+        // MCRL2_SYSTEM_SPECIFIC_ALLOCA(vars,variable, max_len);
+        // MCRL2_SYSTEM_SPECIFIC_ALLOCA(vals,atermpp::aterm, max_len);
 
         size_t len = 0;
         bool matches = true;
@@ -784,11 +792,11 @@ atermpp::aterm_appl RewriterJitty::rewrite_internal(
         ; opids != jitty_eqns.end()
         ; ++opids )
     {
-      const size_t j=opids->first.value(); 
+      const size_t j=opids->first.value();
       make_jitty_strat_sufficiently_larger(j);
       if (jitty_strat[j] == NULL)
       {
-        jitty_strat[j] = create_strategy(opids->second, this);
+        jitty_strat[j] = create_strategy(opids->second);
       }
     }
     need_rebuild = false;
@@ -798,9 +806,9 @@ atermpp::aterm_appl RewriterJitty::rewrite_internal(
   return a;
 }
 
-RewriteStrategy RewriterJitty::getStrategy()
+rewrite_strategy RewriterJitty::getStrategy()
 {
-  return GS_REWR_JITTY;
+  return jitty;
 }
 }
 }
