@@ -22,8 +22,6 @@
 
 using namespace mcrl2;
 using namespace mcrl2::data;
-using namespace mcrl2::data::sort_bag;
-using namespace mcrl2::data::sort_fbag;
 
 // test whether parsing s returns an expression matching predicate p.
 // Furthermore check whether the expression does not satisfy q.
@@ -58,27 +56,27 @@ void bag_expression_test()
   variable_vector v;
   v.push_back(parse_variable("b:Bag(Nat)"));
 
-  BOOST_CHECK(is_bag(bag(sort_nat::nat())));
-  BOOST_CHECK(!is_bag(sort_nat::nat()));
+  BOOST_CHECK(sort_bag::is_bag(sort_bag::bag(sort_nat::nat())));
+  BOOST_CHECK(!sort_bag::is_bag(sort_nat::nat()));
 
-  test_data_expression("{x : Nat | x}", v, is_bagconstructor_application, is_bagin_application);
-  test_data_expression("1 in b", v, is_bagin_application, is_bagjoin_application);
-  test_data_expression("{} + b", v, is_bagjoin_application, is_bagintersect_application);
-  test_data_expression("(({} + b) - {20:1}) * {40:5}", v, is_bagintersect_application, is_less_application<data_expression>);
-  test_data_expression("{10:count(20,b)} < b", v, is_less_application<data_expression>, is_bagcomprehension_application);
-  test_data_expression("b <= {20:2}", v, is_less_equal_application<data_expression>, is_set2bag_application);
-  test_data_expression("Set2Bag({20,30,40})", v, is_set2bag_application, is_bagjoin_application);
-  test_data_expression("{20:2} + Set2Bag({20,30,40})", v, is_bagjoin_application, is_less_equal_application<data_expression>);
-  test_data_expression("b <= {20:2} + Set2Bag({20,30,40})", v, is_less_equal_application<data_expression>, is_bagconstructor_application);
+  test_data_expression("{x : Nat | x}", v, sort_bag::is_constructor_application, sort_bag::is_in_application);
+  test_data_expression("1 in b", v, sort_bag::is_in_application, sort_bag::is_join_application);
+  test_data_expression("{} + b", v, sort_bag::is_join_application, sort_bag::is_intersection_application);
+  test_data_expression("(({} + b) - {20:1}) * {40:5}", v, sort_bag::is_intersection_application, is_less_application<data_expression>);
+  test_data_expression("{10:count(20,b)} < b", v, is_less_application<data_expression>, sort_bag::is_bag_comprehension_application);
+  test_data_expression("b <= {20:2}", v, is_less_equal_application<data_expression>, sort_bag::is_set2bag_application);
+  test_data_expression("Set2Bag({20,30,40})", v, sort_bag::is_set2bag_application, sort_bag::is_join_application);
+  test_data_expression("{20:2} + Set2Bag({20,30,40})", v, sort_bag::is_join_application, is_less_equal_application<data_expression>);
+  test_data_expression("b <= {20:2} + Set2Bag({20,30,40})", v, is_less_equal_application<data_expression>, sort_bag::is_constructor_application);
 
   data_expression e = parse_data_expression("{20:1}", v.begin(), v.end());
-  BOOST_CHECK(is_bagconstructor_application(normaliser(e)));
+  BOOST_CHECK(sort_bag::is_constructor_application(normaliser(e)));
 
   e = parse_data_expression("{20:4, 30:3, 40:2}", v.begin(), v.end());
-  BOOST_CHECK(is_bagconstructor_application(normaliser(e)));
+  BOOST_CHECK(sort_bag::is_constructor_application(normaliser(e)));
 
   e = parse_data_expression("{10:count(20,b)}", v.begin(), v.end());
-  BOOST_CHECK(is_bagconstructor_application(normaliser(e)));
+  BOOST_CHECK(sort_bag::is_constructor_application(normaliser(e)));
 }
 
 int test_main(int argc, char** argv)
