@@ -16,6 +16,7 @@
 #include "mcrl2/atermpp/aterm_init.h"
 #include "mcrl2/atermpp/deque.h"
 #include "mcrl2/core/print.h"
+#include "mcrl2/data/detail/enumerator_variable_limit.h"
 #include "mcrl2/data/function_symbol.h"
 #include "mcrl2/data/enumerator.h"
 #include "mcrl2/data/nat.h"
@@ -248,6 +249,13 @@ void test6()
   }
 }
 
+void test_enumerator_variable_limit()
+{
+  BOOST_CHECK(data::detail::get_enumerator_variable_limit() == 1000);
+  data::detail::set_enumerator_variable_limit(100);
+  BOOST_CHECK(data::detail::get_enumerator_variable_limit() == 100);
+}
+
 int test_main(int argc, char* argv[])
 {
   MCRL2_ATERMPP_INIT_DEBUG(argc, argv)
