@@ -97,7 +97,7 @@ class Invariant_Eliminator
     /// to 0, no time limit will be enforced
     Invariant_Eliminator(
       const mcrl2::lps::specification& a_lps,
-      const mcrl2::data::rewriter::strategy a_rewrite_strategy = mcrl2::data::rewriter::jitty,
+      const mcrl2::data::rewriter::strategy a_rewrite_strategy = data::jitty,
       const int a_time_limit = 0,
       const bool a_path_eliminator = false,
       const mcrl2::data::detail::smt_solver_type a_solver_type = mcrl2::data::detail::solver_type_cvc,
