@@ -19,7 +19,6 @@
 #include <stdexcept>
 #include <string>
 #include <vector>
-#include <boost/iterator/transform_iterator.hpp>
 #include <boost/iterator/iterator_facade.hpp>
 #include "mcrl2/utilities/logger.h"
 #include "mcrl2/atermpp/indexed_set.h"
@@ -29,10 +28,12 @@
 #include "mcrl2/data/find.h"
 #include "mcrl2/data/parse.h"
 #include "mcrl2/data/print.h"
+#include "mcrl2/data/rewrite_strategy.h"
+#include "mcrl2/data/selection.h"
 #include "mcrl2/lps/find.h"
 #include "mcrl2/lps/parse.h"
 #include "mcrl2/lps/next_state_generator.h"
-#include "mcrl2/lps/detail/instantiate_global_variables.h"
+#include "mcrl2/utilities/detail/memory_utility.h"
 
 // For backwards compatibility
 //using namespace mcrl2::log;
@@ -43,26 +44,6 @@ namespace mcrl2 {
 
 namespace lps {
 
-inline
-data::rewriter::strategy parse_rewriter_strategy(const std::string& rewriter_strategy)
-{
-  if (rewriter_strategy == "jitty")
-  {
-		return data::rewriter::jitty;
-  }
-#ifdef MCRL2_JITTYC_AVAILABLE
-  else if (rewriter_strategy == "jittyc")
-  {
-		return data::rewriter::jitty_compiling;
-  }
-#endif
-  else
-  {
-    throw std::runtime_error("Error: unknown rewriter strategy " + rewriter_strategy + "!");
-  }
-  return data::rewriter::jitty;
-}
-
 /// \brief Generates possible values of the data type (at most max_size).
 inline
 std::vector<std::string> generate_values(const data::data_specification& dataspec, const data::sort_expression& s, std::size_t max_size = 1000)
@@ -207,6 +188,12 @@ class pins_data_type
       return m_indexed_set[x];
     }
 
+    /// \brief Returns the value at index i
+    atermpp::aterm get(size_t i)
+    {
+      return m_indexed_set.get(i);
+    }
+
     /// \brief Returns the indexed_set holding the values
     atermpp::indexed_set& indexed_set()
     {
@@ -229,12 +216,12 @@ class state_data_type: public pins_data_type
 
     std::size_t expression2index(const data::data_expression& x)
     {
-      return m_indexed_set[m_generator.expression2aterm(x)];
+      return m_indexed_set[m_generator.get_internal_state_argument(x)];
     }
 
     data::data_expression index2expression(std::size_t i) const
     {
-      return m_generator.aterm2expression(m_indexed_set.get(i));
+      return m_generator.get_state_argument(m_indexed_set.get(i));
     }
 
   public:
@@ -252,9 +239,7 @@ class state_data_type: public pins_data_type
 
     std::size_t deserialize(const std::string& s)
     {
-      ATerm t = atermpp::read_from_string(s);
-      data::data_expression d = atermpp::aterm_appl(reinterpret_cast<ATermAppl>(t));
-      return expression2index(d);
+      return expression2index(data::data_expression(atermpp::read_from_string(s)));
     }
 
     std::string print(int i) const
@@ -264,8 +249,7 @@ class state_data_type: public pins_data_type
 
     std::size_t parse(const std::string& s)
     {
-      data::data_expression e = data::parse_data_expression(s, m_generator.get_specification().data());
-      return expression2index(e);
+      return expression2index(data::parse_data_expression(s, m_generator.get_specification().data()));
     }
 
     const std::string& name() const
@@ -285,19 +269,6 @@ class action_label_data_type: public pins_data_type
   protected:
     std::string m_name;
 
-    std::size_t expression2index(const lps::multi_action& x)
-    {
-      atermpp::aterm_appl a = lps::detail::multi_action_to_aterm(x);
-      return m_indexed_set[a];
-    }
-
-    lps::multi_action index2expression(std::size_t i) const
-    {
-      ATerm a = m_indexed_set.get(i);
-      atermpp::aterm_appl t = reinterpret_cast<ATermAppl>(a);
-      return t;
-    }
-
   public:
     action_label_data_type(lps::next_state_generator& generator)
       : pins_data_type(generator, false)
@@ -307,26 +278,23 @@ class action_label_data_type: public pins_data_type
 
     std::string serialize(int i) const
     {
-      atermpp::aterm_appl a = lps::detail::multi_action_to_aterm(index2expression(i));
-      return a.to_string();
+      return m_indexed_set.get(i).to_string();
     }
 
     std::size_t deserialize(const std::string& s)
     {
-      ATerm a = atermpp::read_from_string(s);
-      atermpp::aterm_appl t = reinterpret_cast<ATermAppl>(a);
-      return expression2index(t);
+      return m_indexed_set[atermpp::read_from_string(s)];
     }
 
     std::string print(int i) const
     {
-      return lps::pp(index2expression(i));
+      return lps::pp(lps::multi_action(atermpp::aterm_appl(m_indexed_set.get(i))));
     }
 
     std::size_t parse(const std::string& s)
     {
       lps::multi_action m = lps::parse_multi_action(s, m_generator.get_specification().action_labels(), m_generator.get_specification().data());
-      return expression2index(m);
+      return m_indexed_set[detail::multi_action_to_aterm(m)];
     }
 
     const std::string& name() const
@@ -345,15 +313,15 @@ class pins
 {
   public:
     typedef int* ltsmin_state_type; /**< the state type used by LTSMin */
-    typedef lps::next_state_generator::state_type next_state_type; /**< the state type used by the next state generator */
 
   protected:
     size_t m_group_count;
     size_t m_state_length; /**< the number of process parameters */
     std::vector<std::vector<size_t> > m_read_group;
     std::vector<std::vector<size_t> > m_write_group;
+    lps::specification m_specification;
     lps::next_state_generator m_generator;
-    atermpp::function_symbol m_state_fun; /**< the function symbol used for 'next states' */
+    lps::next_state_generator::substitution_t m_substitution;
     std::vector<std::string> m_process_parameter_names;
 
     // The type mappings
@@ -493,39 +461,6 @@ class pins
       }
     }
 
-    /// \brief Converts state component represented as integers into aterms (in the next state format).
-    /// It is used in the function initial_state, to avoid creating a temporary aterm_appl object.
-    template <typename DataTypeMapIter>
-    struct state_component_converter: public std::unary_function<int, atermpp::aterm>
-    {
-      DataTypeMapIter& iter;
-
-      state_component_converter(DataTypeMapIter& iter_)
-        : iter(iter_)
-      {}
-
-      atermpp::aterm operator()(int i) const
-      {
-        return (*iter++)->indexed_set().get(i);
-      }
-    };
-
-    template <typename DataTypeMapIter>
-    state_component_converter<DataTypeMapIter> make_state_component_converter(DataTypeMapIter& i) const
-    {
-      return state_component_converter<DataTypeMapIter>(i);
-    }
-
-    /// \brief Converts an ltsmin_state to the corresponding aterm.
-    atermpp::aterm_appl initial_state(ltsmin_state_type const& src, std::size_t nparams) const
-    {
-      std::vector<pins_data_type*>::const_iterator i = m_data_types.begin();
-      return atermpp::aterm_appl(m_state_fun,
-                                 boost::make_transform_iterator(src, make_state_component_converter(i)),
-                                 boost::make_transform_iterator(src + nparams, make_state_component_converter(i))
-                                );
-    }
-
   public:
     typedef std::size_t datatype_index; /**< the index type for datatype maps */
 
@@ -541,17 +476,22 @@ class pins
       return m_generator.get_specification().process().action_summands().size();
     }
 
+    static lps::specification load_specification(const std::string& filename)
+    {
+      lps::specification specification;
+      specification.load(filename);
+      return specification;
+    }
+
     /// \brief Constructor
     /// \param filename The name of a file containing an mCRL2 specification
     /// \param rewriter_strategy The rewriter strategy used for generating next states
     pins(const std::string& filename, const std::string& rewriter_strategy)
-      : m_generator(filename, parse_rewriter_strategy(rewriter_strategy))
+      : m_specification(load_specification(filename)),
+        m_generator(m_specification, data::rewriter(m_specification.data(), data::used_data_equation_selector(m_specification.data(),lps::find_function_symbols(m_specification),m_specification.global_variables()), data::parse_rewrite_strategy(rewriter_strategy)))
     {
       initialize_read_write_groups();
 
-      // TODO: this is ugly, is there a better way to create states?
-      m_state_fun = atermpp::function_symbol("STATE", process_parameter_count(), false);
-
       // store the process parameter names in a vector, to have random access to them
       data::variable_list params = m_generator.get_specification().process().process_parameters();
       for (data::variable_list::iterator i = params.begin(); i != params.end(); ++i)
@@ -674,11 +614,10 @@ class pins
     /// \brief Assigns the initial state to s.
     void get_initial_state(ltsmin_state_type& s)
     {
-      ATerm a = m_generator.initial_state();
-      atermpp::aterm_appl init(reinterpret_cast<ATermAppl>(a));
-	    for (size_t i = 0; i < m_state_length; ++i)
-	    {
-	      s[i] = state_type_map(i)[init(i)];
+      lps::next_state_generator::internal_state_t initial_state = m_generator.internal_initial_state();
+      for (size_t i = 0; i < m_state_length; i++)
+      {
+        s[i] = state_type_map(i)[initial_state(i)];
       }
     }
 
@@ -714,16 +653,21 @@ class pins
     void next_state_all(ltsmin_state_type const& src, StateFunction& f, ltsmin_state_type const& dest, int* const& labels)
     {
       std::size_t nparams = process_parameter_count();
-      atermpp::aterm_appl init = initial_state(src, nparams);
-      next_state_generator::iterator i = m_generator.begin(init);
-      while (++i)
+      MCRL2_SYSTEM_SPECIFIC_ALLOCA(state_arguments, lps::next_state_generator::internal_state_argument_t, nparams);
+      for (size_t i = 0; i < nparams; i++)
       {
-        const lps::next_state_generator::state_type& s = *i;
-        for (size_t i = 0; i < nparams; ++i)
+        state_arguments[i] = state_type_map(i).get(src[i]);
+      }
+      lps::next_state_generator::internal_state_t source = m_generator.get_internal_state(state_arguments);
+
+      for (next_state_generator::iterator i = m_generator.begin(source, &m_substitution); i; i++)
+      {
+        lps::next_state_generator::internal_state_t destination = i->internal_state();
+        for (size_t j = 0; j < nparams; j++)
         {
-          dest[i] = state_type_map(i)[s[i]];
+          dest[j] = state_type_map(j)[destination(j)];
         }
-        labels[0] = action_label_type_map()[detail::multi_action_to_aterm(s.label())];
+        labels[0] = action_label_type_map()[detail::multi_action_to_aterm(i->action())];
         f(dest, labels);
       }
     }
@@ -749,17 +693,22 @@ class pins
     void next_state_long(ltsmin_state_type const& src, std::size_t group, StateFunction& f, ltsmin_state_type const& dest, int* const& labels)
     {
       std::size_t nparams = process_parameter_count();
-      atermpp::aterm_appl init = initial_state(src, nparams);
-      next_state_generator::iterator i = m_generator.begin(init, group);
-      while (++i)
+      MCRL2_SYSTEM_SPECIFIC_ALLOCA(state_arguments, lps::next_state_generator::internal_state_argument_t, nparams);
+      for (size_t i = 0; i < nparams; i++)
       {
-        const lps::next_state_generator::state_type& s = *i;
-        for (size_t i = 0; i < nparams; ++i)
+        state_arguments[i] = state_type_map(i).get(src[i]);
+      }
+      lps::next_state_generator::internal_state_t source = m_generator.get_internal_state(state_arguments);
+
+      for (next_state_generator::iterator i = m_generator.begin(source, &m_substitution, group); i; i++)
+      {
+        lps::next_state_generator::internal_state_t destination = i->internal_state();
+        for (size_t j = 0; j < nparams; j++)
         {
-          dest[i] = state_type_map(i)[s[i]];
+          dest[j] = state_type_map(j)[destination(j)];
         }
-        labels[0] = action_label_type_map()[detail::multi_action_to_aterm(s.label())];
-        f(dest, labels, group);
+        labels[0] = action_label_type_map()[detail::multi_action_to_aterm(i->action())];
+        f(dest, labels);
       }
     }
 
