@@ -15,8 +15,10 @@
 #include <boost/lexical_cast.hpp>
 
 #include "mcrl2/core/print.h"
+#include "mcrl2/data/parse.h"
 #include "mcrl2/data/print.h"
 #include "mcrl2/lps/traverser.h"
+#include "mcrl2/lps/state.h"
 
 namespace mcrl2
 {
@@ -285,6 +287,14 @@ struct printer: public lps::add_traverser_sort_expressions<data::detail::printer
 
       // print deadlock summands
       print_numbered_list(x.deadlock_summands(), separator, number_separator, x.action_summands().size() + 1, true);
+
+      // print delta if there are no summands
+      if (x.action_summands().empty() && (x.deadlock_summands().empty()))
+      {
+        deadlock_summand_vector v;
+        v.push_back(deadlock_summand(data::variable_list(), data::sort_bool::true_(), lps::deadlock(data::parse_data_expression("0"))));
+        print_numbered_list(v, separator, number_separator, 1, true);
+      }
     }
     else
     {
@@ -302,6 +312,14 @@ struct printer: public lps::add_traverser_sort_expressions<data::detail::printer
         opener = separator;
       }
       print_list(x.deadlock_summands(), opener, closer, separator);
+
+      // print delta if there are no summands
+      if (x.action_summands().empty() && (x.deadlock_summands().empty()))
+      {
+        deadlock_summand_vector v;
+        v.push_back(deadlock_summand(data::variable_list(), data::sort_bool::true_(), lps::deadlock(data::parse_data_expression("0"))));
+        print_list(v, opener, closer, separator);
+      }
     }
 
     derived().print(";\n");
@@ -320,6 +338,24 @@ struct printer: public lps::add_traverser_sort_expressions<data::detail::printer
     derived().print("\n");
     derived().leave(x);
   }
+
+  void operator()(const lps::state &x)
+  {
+    derived().enter(x);
+    derived().print("state(");
+    bool first = true;
+    for (lps::state::const_iterator i = x.begin(); i != x.end(); i++)
+    {
+      if (!first)
+      {
+        derived().print(", ");
+      }
+      first = false;
+      print_expression(*i);
+    }
+    derived().print(")");
+    derived().leave(x);
+  }
 };
 
 } // namespace detail
