@@ -26,8 +26,20 @@ namespace lps
 //         The length is determined at runtime. 
 class state: public atermpp::vector < mcrl2::data::data_expression > 
 {
+  public:
+    state()
+    {
+    }
+
+    state(data::data_expression_list arguments):
+      atermpp::vector<mcrl2::data::data_expression>(arguments.begin(), arguments.end())
+    {
+    }
 };
 
+// template function overloads
+std::string pp(const lps::state& x);
+
 } // namespace lps
 } // namespace mcrl2
 
