@@ -100,8 +100,6 @@ class suminst_algorithm: public lps::detail::lps_algorithm
         {
           mCRL2log(log::debug, "suminst") << "enumerating condition: " << data::pp(s.condition()) << std::endl;
 
-          log::mcrl2_logger::indent();
-
           for (enumerator_type::iterator i=m_enumerator.begin(boost::make_iterator_range(variables), s.condition());
                   i != m_enumerator.end(); ++i)
           {
@@ -114,8 +112,6 @@ class suminst_algorithm: public lps::detail::lps_algorithm
             ++nr_summands;
           }
 
-          log::mcrl2_logger::unindent();
-
           if (nr_summands == 0)
           {
             mCRL2log(log::verbose, "suminst") << "all valuations for the variables in the condition of this summand reduce to false; removing this summand" << std::endl;
