@@ -11,23 +11,28 @@
 
 #include <iostream>
 #include <string>
-#include <boost/test/minimal.hpp>
-#include <mcrl2/lps/specification.h>
-#include <mcrl2/lps/binary.h>
-#include <mcrl2/lps/linearise.h>
+#include <boost/test/included/unit_test_framework.hpp>
+
+#include "mcrl2/utilities/test_utilities.h"
+
+#include "mcrl2/lps/specification.h"
+#include "mcrl2/lps/binary.h"
+#include "mcrl2/lps/linearise.h"
 #include "mcrl2/lps/detail/test_input.h"
-#include "mcrl2/core/garbage_collection.h"
 #include "mcrl2/atermpp/aterm_init.h"
 
 using namespace mcrl2;
 using namespace mcrl2::data;
 using namespace mcrl2::lps;
+using mcrl2::utilities::collect_after_test_case;
+
+BOOST_GLOBAL_FIXTURE(collect_after_test_case)
+
 
 ///All process parameters of sort D should have been translated to
 ///parameters of sort Bool. This leaves only parameters of sort Bool and Pos.
-void test_case_1()
+BOOST_AUTO_TEST_CASE(case_1)
 {
-  std::clog << "test case 1" << std::endl;
   const std::string text(
     "sort D = struct d1|d2;\n"
     "act a;\n"
@@ -40,19 +45,18 @@ void test_case_1()
   specification s1 = s0;
   binary_algorithm<rewriter>(s1, r).run();
 
-  deprecated::summand_list summands1 = deprecated::linear_process_summands(s1.process());
   variable_list parameters1 = s1.process().process_parameters();
 
   int bool_param_count = 0;
   for (variable_list::iterator i = parameters1.begin(); i != parameters1.end(); ++i)
   {
-    BOOST_CHECK(i->sort() == sort_bool::bool_());
+    BOOST_CHECK_EQUAL(i->sort(), sort_bool::bool_());
     if (i->sort() == sort_bool::bool_())
     {
       ++bool_param_count;
     }
   }
-  BOOST_CHECK(bool_param_count == 1);
+  BOOST_CHECK_EQUAL(bool_param_count, 1);
 }
 
 /*
@@ -63,9 +67,8 @@ void test_case_1()
  * and should be replaced in nextstate.
  * The initial state should be altered accordingly.
  */
-void test_case_2()
+BOOST_AUTO_TEST_CASE(case_2)
 {
-  std::clog << "test case 2" << std::endl;
   const std::string text(
     "sort D = struct d1|d2|d3|d4|d5|d6|d7|d8;\n"
     "act a;\n"
@@ -77,20 +80,19 @@ void test_case_2()
   rewriter r(s0.data());
   specification s1 = s0;
   binary_algorithm<rewriter>(s1, r).run();
-  deprecated::summand_list summands1 = deprecated::linear_process_summands(s1.process());
 
   int bool_param_count = 0;
   for (variable_list::iterator i = s1.process().process_parameters().begin();
        i != s1.process().process_parameters().end();
        ++i)
   {
-    BOOST_CHECK(i->sort() == sort_bool::bool_());
+    BOOST_CHECK_EQUAL(i->sort(), sort_bool::bool_());
     if (i->sort() == sort_bool::bool_())
     {
       ++bool_param_count;
     }
   }
-  BOOST_CHECK(bool_param_count == 3);
+  BOOST_CHECK_EQUAL(bool_param_count, 3);
 }
 
 /*
@@ -101,9 +103,8 @@ void test_case_2()
  * and should be replaced in nextstate.
  * The initial state should be altered accordingly.
  */
-void test_case_3()
+BOOST_AUTO_TEST_CASE(case_3)
 {
-  std::clog << "test case 3" << std::endl;
   const std::string text(
     "sort D = struct d1|d2|d3|d4|d5|d6|d7;\n"
     "act a;\n"
@@ -115,20 +116,19 @@ void test_case_3()
   rewriter r(s0.data());
   specification s1 = s0;
   binary_algorithm<rewriter>(s1, r).run();
-  deprecated::summand_list summands1 = deprecated::linear_process_summands(s1.process());
 
   int bool_param_count = 0;
   for (variable_list::iterator i = s1.process().process_parameters().begin();
        i != s1.process().process_parameters().end();
        ++i)
   {
-    BOOST_CHECK(i->sort() == sort_bool::bool_());
+    BOOST_CHECK_EQUAL(i->sort(), sort_bool::bool_());
     if (i->sort() == sort_bool::bool_())
     {
       ++bool_param_count;
     }
   }
-  BOOST_CHECK(bool_param_count == 3);
+  BOOST_CHECK_EQUAL(bool_param_count, 3);
 }
 
 /*
@@ -138,9 +138,8 @@ void test_case_3()
  *
  * Note there is parameter of sort Pos because of linearisation.
  */
-void test_case_4()
+BOOST_AUTO_TEST_CASE(case_4)
 {
-  std::clog << "test case 4" << std::endl;
   const std::string text(
     "sort D = struct d1|d2;\n"
     "act a,b:D;\n"
@@ -152,7 +151,6 @@ void test_case_4()
   rewriter r(s0.data());
   specification s1 = s0;
   binary_algorithm<rewriter>(s1, r).run();
-  deprecated::summand_list summands1 = deprecated::linear_process_summands(s1.process());
 
   int bool_param_count = 0;
   for (variable_list::iterator i = s1.process().process_parameters().begin();
@@ -165,7 +163,7 @@ void test_case_4()
       ++bool_param_count;
     }
   }
-  BOOST_CHECK(bool_param_count == 2);
+  BOOST_CHECK_EQUAL(bool_param_count, 2);
 }
 
 /*
@@ -176,9 +174,8 @@ void test_case_4()
  * and should be replaced in nextstate.
  * The initial state should be altered accordingly.
  */
-void test_case_5()
+BOOST_AUTO_TEST_CASE(case_5)
 {
-  std::clog << "test case 5" << std::endl;
   const std::string text(
     "sort D = struct d1|d2|d3|d4|d5|d6|d7|d8|d9;\n"
     "act a;\n"
@@ -190,20 +187,19 @@ void test_case_5()
   rewriter r(s0.data());
   specification s1 = s0;
   binary_algorithm<rewriter>(s1, r).run();
-  deprecated::summand_list summands1 = deprecated::linear_process_summands(s1.process());
 
   int bool_param_count = 0;
   for (variable_list::iterator i = s1.process().process_parameters().begin();
        i != s1.process().process_parameters().end();
        ++i)
   {
-    BOOST_CHECK(i->sort() == sort_bool::bool_());
+    BOOST_CHECK_EQUAL(i->sort(), sort_bool::bool_());
     if (i->sort() == sort_bool::bool_())
     {
       ++bool_param_count;
     }
   }
-  BOOST_CHECK(bool_param_count == 4);
+  BOOST_CHECK_EQUAL(bool_param_count, 4);
 }
 
 /*
@@ -216,9 +212,8 @@ void test_case_5()
  * and should be replaced in nextstate.
  * The initial state should be altered accordingly.
  */
-void test_case_6()
+BOOST_AUTO_TEST_CASE(case_6)
 {
-  std::clog << "test case 6" << std::endl;
   const std::string text(
     "sort D = struct d1(E) | d2(E);\n"
     "     E = struct e1 | e2;\n"
@@ -231,28 +226,26 @@ void test_case_6()
   rewriter r(s0.data());
   specification s1 = s0;
   binary_algorithm<rewriter>(s1, r).run();
-  deprecated::summand_list summands1 = deprecated::linear_process_summands(s1.process());
 
   int bool_param_count = 0;
   for (variable_list::iterator i = s1.process().process_parameters().begin();
        i != s1.process().process_parameters().end();
        ++i)
   {
-    BOOST_CHECK(i->sort() == sort_bool::bool_());
+    BOOST_CHECK_EQUAL(i->sort(), sort_bool::bool_());
     if (i->sort() == sort_bool::bool_())
     {
       ++bool_param_count;
     }
   }
-  BOOST_CHECK(bool_param_count == 2);
+  BOOST_CHECK_EQUAL(bool_param_count, 2);
 }
 
 // This test case shows a bug where apparently d1 and d2 are mapped to the
 // same boolean value. Test case was provided by Jan Friso Groote along with
 // bug 623.
-void test_bug_623()
+BOOST_AUTO_TEST_CASE(bug_623)
 {
-  std::clog << "test bug 623" << std::endl;
   const std::string text(
     "sort D;\n"
     "cons d1,d2:D;\n"
@@ -269,14 +262,14 @@ void test_bug_623()
   for (action_summand_vector::const_iterator i = summands1.begin(); i != summands1.end(); ++i)
   {
     data_expression_list next_state = i->next_state(s1.process().process_parameters());
-    BOOST_CHECK(next_state.size() == 2);
-    BOOST_CHECK(*next_state.begin() != *(++next_state.begin()));
+    BOOST_CHECK_EQUAL(next_state.size(), 2);
+    BOOST_CHECK_NE(*next_state.begin(), *(++next_state.begin()));
     std::clog << "erroneous next state " << data::pp(next_state) << std::endl;
   }
 
 }
 
-void test_abp()
+BOOST_AUTO_TEST_CASE(abp)
 {
   specification spec = linearise(lps::detail::ABP_SPECIFICATION());
   std::clog << "--- before ---\n" << lps::pp(spec) << std::endl;
@@ -287,25 +280,9 @@ void test_abp()
   core::garbage_collect();
 }
 
-int test_main(int ac, char** av)
+boost::unit_test::test_suite* init_unit_test_suite(int argc, char* argv[])
 {
-  MCRL2_ATERMPP_INIT(ac, av)
-
-  test_case_1();
-  core::garbage_collect();
-  test_case_2();
-  core::garbage_collect();
-  test_case_3();
-  core::garbage_collect();
-  test_case_4();
-  core::garbage_collect();
-  test_case_5();
-  core::garbage_collect();
-  test_case_6();
-  core::garbage_collect();
-  test_bug_623();
-  core::garbage_collect();
-  test_abp();
+  MCRL2_ATERMPP_INIT(argc, argv)
 
   return 0;
 }
