@@ -15,13 +15,14 @@
 #include <string>
 #include <boost/test/minimal.hpp>
 #include <boost/algorithm/string.hpp>
-#include "mcrl2/core/text_utility.h"
+#include "mcrl2/utilities/text_utility.h"
 #include "mcrl2/data/rewriter.h"
 #include "mcrl2/lps/linearise.h"
 #include "mcrl2/lps/parse.h"
 #include "mcrl2/lps/constelm.h"
 #include "mcrl2/lps/specification.h"
 #include "mcrl2/lps/detail/specification_property_map.h"
+#include "mcrl2/lps/detail/test_input.h"
 #include "mcrl2/core/garbage_collection.h"
 #include "mcrl2/atermpp/aterm_init.h"
 
@@ -397,9 +398,8 @@ void test_constelm(const std::string& message, const std::string& spec_text, con
 {
   specification spec = parse_linear_process_specification(spec_text);
   data::rewriter R(spec.data());
-  bool verbose = false;
   bool instantiate_free_variables = false;
-  constelm(spec, R, verbose, instantiate_free_variables);
+  constelm(spec, R, instantiate_free_variables);
   lps::detail::specification_property_map info(spec);
   BOOST_CHECK(data::detail::compare_property_maps(message, info, expected_result));
   core::garbage_collect();
@@ -422,50 +422,10 @@ void test_constelm()
 
 void test_abp()
 {
-  const std::string ABP_SPEC =
-    "% This file contains the alternating bit protocol, as described in W.J.    \n"
-    "% Fokkink, J.F. Groote and M.A. Reniers, Modelling Reactive Systems.       \n"
-    "%                                                                          \n"
-    "% The only exception is that the domain D consists of two data elements to \n"
-    "% facilitate simulation.                                                   \n"
-    "                                                                           \n"
-    "sort                                                                       \n"
-    "  D     = struct d1 | d2;                                                  \n"
-    "  Error = struct e;                                                        \n"
-    "                                                                           \n"
-    "act                                                                        \n"
-    "  r1,s4: D;                                                                \n"
-    "  s2,r2,c2: D # Bool;                                                      \n"
-    "  s3,r3,c3: D # Bool;                                                      \n"
-    "  s3,r3,c3: Error;                                                         \n"
-    "  s5,r5,c5: Bool;                                                          \n"
-    "  s6,r6,c6: Bool;                                                          \n"
-    "  s6,r6,c6: Error;                                                         \n"
-    "  i;                                                                       \n"
-    "                                                                           \n"
-    "proc                                                                       \n"
-    "  S(b:Bool)     = sum d:D. r1(d).T(d,b);                                   \n"
-    "  T(d:D,b:Bool) = s2(d,b).(r6(b).S(!b)+(r6(!b)+r6(e)).T(d,b));             \n"
-    "                                                                           \n"
-    "  R(b:Bool)     = sum d:D. r3(d,b).s4(d).s5(b).R(!b)+                      \n"
-    "                  (sum d:D.r3(d,!b)+r3(e)).s5(!b).R(b);                    \n"
-    "                                                                           \n"
-    "  K             = sum d:D,b:Bool. r2(d,b).(i.s3(d,b)+i.s3(e)).K;           \n"
-    "                                                                           \n"
-    "  L             = sum b:Bool. r5(b).(i.s6(b)+i.s6(e)).L;                   \n"
-    "                                                                           \n"
-    "init                                                                       \n"
-    "  allow({r1,s4,c2,c3,c5,c6,i},                                             \n"
-    "    comm({r2|s2->c2, r3|s3->c3, r5|s5->c5, r6|s6->c6},                     \n"
-    "        S(true) || K || L || R(true)                                       \n"
-    "    )                                                                      \n"
-    "  );                                                                       \n"
-    ;
-  specification spec = linearise(ABP_SPEC);
+  specification spec = linearise(lps::detail::ABP_SPECIFICATION());
   data::rewriter R(spec.data());
-  bool verbose = false;
   bool instantiate_free_variables = false;
-  constelm(spec, R, verbose, instantiate_free_variables);
+  constelm(spec, R, instantiate_free_variables);
   BOOST_CHECK(is_well_typed(spec));
   core::garbage_collect();
 }
