@@ -24,7 +24,6 @@
 #include "mcrl2/lts/lts_fsm.h"
 #include "mcrl2/lts/lts_bcg.h"
 #include "mcrl2/lts/lts_dot.h"
-#include "mcrl2/lts/lts_svc.h"
 
 namespace mcrl2
 {
@@ -897,7 +896,8 @@ class bisim_partitioner
               old_counter_trace.resetPosition();
               for (size_t k=0 ; k< old_counter_trace.number_of_actions(); k++)
               {
-                new_counter_trace.addAction(old_counter_trace.nextAction());
+                new_counter_trace.addAction(old_counter_trace.currentAction());
+                old_counter_trace.increasePosition();
               }
               resulting_counter_traces.insert(new_counter_trace);
             }
