@@ -13,7 +13,6 @@
 
 #include <cstdlib> // free
 #include "mcrl2/utilities/detail/memory_utility.h"
-#include "mcrl2/lts/lts_algorithm.h"
 #include "mcrl2/utilities/logger.h"
 #include "mcrl2/lts/lts.h"
 
@@ -39,8 +38,7 @@ void tau_star_reduce(lts<STATE_LABEL_T,ACTION_LABEL_T> &l)
   // Copy the transitions into a local set of transitions, to which we
   // have access.
 
-  const transition_const_range r=l.get_transitions();
-  atermpp::vector < transition > local_transitions(r.begin(),r.end()); 
+  std::vector < transition > local_transitions=l.get_transitions();
 
   size_t* trans_lut = l.get_transition_indices();
   MCRL2_SYSTEM_SPECIFIC_ALLOCA(new_trans_lut,size_t,l.num_states() + 1);
@@ -118,17 +116,17 @@ void tau_star_reduce(lts<STATE_LABEL_T,ACTION_LABEL_T> &l)
   }
 
   free(trans_lut);
-  
+
   // Add the newly generated transitions
   for(std::vector < transition >::const_iterator i=local_transitions.begin();
             i!=local_transitions.end(); ++i)
-  { 
+  {
     if (!l.is_tau(i->label()))
-    { 
+    {
       l.add_transition(*i);
     }
   }
-  
+
   reachability_check(l, true); // Remove unreachable parts.
 }
 
