@@ -38,8 +38,11 @@
 #include "mcrl2/lts/detail/liblts_scc.h"
 #include "mcrl2/lts/detail/liblts_sim.h"
 #include "mcrl2/lts/detail/liblts_tau_star_reduce.h"
-#include "mcrl2/exception.h"
+#include "mcrl2/utilities/exception.h"
 #include "mcrl2/lts/detail/tree_set.h"
+#include "mcrl2/lts/lts_equivalence.h"
+#include "mcrl2/lts/lts_preorder.h"
+#include "mcrl2/lts/sigref.h"
 
 namespace mcrl2
 {
@@ -54,373 +57,6 @@ static bool lts_named_cmp(std::string N[], T a, T b)
 }
 
 
-/** \brief LTS equivalence relations.
- * \details This enumerated type defines equivalence relations on
- * LTSs. They can be used to reduce an LTS or decide whether two LTSs
- * are equivalent. */
-enum lts_equivalence
-{
-  lts_eq_none,             /**< Unknown or no equivalence */
-  lts_eq_bisim,            /**< Strong bisimulation equivalence */
-  lts_eq_branching_bisim,  /**< Branching bisimulation equivalence */
-  lts_eq_divergence_preserving_branching_bisim,
-  /**< Divergence preserving branching bisimulation equivalence */
-  lts_eq_sim,              /**< Strong simulation equivalence */
-  lts_eq_trace,            /**< Strong trace equivalence*/
-  lts_eq_weak_trace,       /**< Weak trace equivalence */
-  lts_red_tau_star,        /**< Tau star reduction */
-  lts_red_determinisation, /**< Used for a determinisation reduction */
-  lts_equivalence_min = lts_eq_none,
-  lts_equivalence_max = lts_red_determinisation
-};
-
-/** \brief LTS preorder relations.
- * \details This enumerated type defines preorder relations on LTSs.
- * They can be used to decide whether one LTS is behaviourally
- * contained in another LTS. */
-enum lts_preorder
-{
-  lts_pre_none,   /**< Unknown or no preorder */
-  lts_pre_sim,    /**< Strong simulation preorder */
-  lts_pre_trace,  /**< Strong trace preorder */
-  lts_pre_weak_trace,   /**< Weak trace preorder */
-  lts_preorder_min = lts_pre_none,
-  lts_preorder_max = lts_pre_weak_trace
-};
-
-static const std::set<lts_equivalence> &initialise_supported_lts_equivalences()
-{
-  static std::set<lts_equivalence> s;
-  for (size_t i = lts_equivalence_min; i<1+(size_t)lts_equivalence_max; ++i)
-  {
-    if (lts_eq_none != (lts_equivalence) i)
-    {
-      s.insert((lts_equivalence) i);
-    }
-  }
-  return s;
-}
-
-/** \brief Gives the set of all supported equivalence on LTSs.
- * \return The set of all supported equivalences on LTSs. */
-inline const std::set<lts_equivalence> &supported_lts_equivalences()
-{
-  static const std::set<lts_equivalence> &s = initialise_supported_lts_equivalences();
-  return s;
-}
-
-static const std::set<lts_preorder> &initialise_supported_lts_preorders()
-{
-  static std::set<lts_preorder> s;
-  for (size_t i = lts_preorder_min; i<1+(size_t)lts_preorder_max; ++i)
-  {
-    if (lts_pre_none != (lts_preorder) i)
-    {
-      s.insert((lts_preorder) i);
-    }
-  }
-  return s;
-}
-
-/** \brief Gives the set of all supported preorders on LTSs.
- * \return The set of all supported preorders on LTSs. */
-
-inline const std::set<lts_preorder> &supported_lts_preorders()
-{
-  static const std::set<lts_preorder> &s = initialise_supported_lts_preorders();
-  return s;
-}
-
-
-static std::string equivalence_desc_strings[] =
-{
-  "identity equivalence",
-  "strong bisimilarity",
-  "branching bisimilarity",
-  "divergence preserving branching bisimilarity",
-  "strong simulation equivalence",
-  "strong trace equivalence",
-  "weak trace equivalence",
-  "tau star reduction",
-  "determinisation reduction"
-};
-
-/** \brief Gives the full name of an equivalence.
- * \param[in] eq The equivalence type.
- * \return The full, descriptive name of the equivalence specified by \a eq. */
-inline std::string name_of_equivalence(const lts_equivalence eq)
-{
-  return equivalence_desc_strings[eq];
-}
-
-static std::string preorder_desc_strings[] =
-{
-  "unknown preorder",
-  "strong simulation preorder",
-  "strong trace preorder",
-  "weak trace preorder"
-};
-
-/** \brief Gives the full name of a preorder.
- * \param[in] pre The preorder type.
- * \return The full, descriptive name of the preorder specified by \a pre. */
-inline std::string name_of_preorder(const lts_preorder pre)
-{
-  return preorder_desc_strings[pre];
-}
-
-/** \brief Determines the equivalence from a string.
- * \details The following strings may be used:
- * \li "none" for identity equivalence;
- * \li "bisim" for strong bisimilarity;
- * \li "branching-bisim" for branching bisimilarity;
- * \li "dpbranching-bisim" for divergence preserving branching bisimilarity;
- * \li "sim" for strong simulation equivalence;
- * \li "trace" for strong trace equivalence;
- * \li "weak-trace" for weak trace equivalence;
- *
- * \param[in] s The string specifying the equivalence.
- * \return The equivalence type specified by \a s.
- * If \a s is none of the above values then \a lts_eq_none is returned. */
-inline lts_equivalence parse_equivalence(std::string const& s)
-{
-  if (s == "bisim")
-  {
-    return lts_eq_bisim;
-  }
-  else if (s == "branching-bisim")
-  {
-    return lts_eq_branching_bisim;
-  }
-  else if (s == "dpbranching-bisim")
-  {
-    return lts_eq_divergence_preserving_branching_bisim;
-  }
-  else if (s == "sim")
-  {
-    return lts_eq_sim;
-  }
-  else if (s == "trace")
-  {
-    return lts_eq_trace;
-  }
-  else if (s == "weak-trace")
-  {
-    return lts_eq_weak_trace;
-  }
-  else if (s == "tau-star")
-  {
-    return lts_red_tau_star;
-  }
-  else if (s == "determinisation")
-  {
-    return lts_red_determinisation;
-  }
-  else
-  {
-    return lts_eq_none;
-  }
-}
-
-static std::string equivalence_strings[] =
-{
-  "none",
-  "bisim",
-  "branching-bisim",
-  "dpbranching-bisim",
-  "sim",
-  "trace",
-  "weak-trace",
-  "tau-star",
-  "determinisation"
-};
-
-/** \brief Gives the short name of an equivalence.
- * \param[in] eq The equivalence type.
- * \return A short string representing the equivalence specified by \a
- * eq. The returned value is one of the strings listed for
- * \ref parse_equivalence. */
-inline std::string string_for_equivalence(const lts_equivalence eq)
-{
-  return equivalence_strings[eq];
-}
-
-/** \brief Determines the preorder from a string.
- * \details The following strings may be used:
- * \li "sim" for strong simulation preorder;
- * \li "trace" for strong trace preorder;
- * \li "weak-trace" for weak trace preorder.
- *
- * \param[in] s The string specifying the preorder.
- * \return The preorder type specified by \a s.
- * If \a s is none of the above values then \a lts_pre_none is returned. */
-inline lts_preorder parse_preorder(std::string const& s)
-{
-  if (s == "sim")
-  {
-    return lts_pre_sim;
-  }
-  else if (s == "trace")
-  {
-    return lts_pre_trace;
-  }
-  else if (s == "weak-trace")
-  {
-    return lts_pre_weak_trace;
-  }
-  else
-  {
-    return lts_pre_none;
-  }
-}
-
-
-static std::string preorder_strings[] =
-{
-  "unknown",
-  "sim",
-  "trace",
-  "weak-trace"
-};
-
-/** \brief Gives the short name of a preorder.
- * \param[in] pre The preorder type.
- * \return A short string representing the preorder specified by \a
- * pre. The returned value is one of the strings listed for
- * \ref parse_preorder. */
-inline std::string string_for_preorder(const lts_preorder pre)
-{
-  return preorder_strings[pre];
-}
-
-
-/** \brief Gives a textual list describing supported equivalences on LTSs.
- * \param[in] default_equivalence The equivalence that should be marked
- *                                as default (or \a lts_eq_none for no
- *                                default).
- * \param[in] supported           The equivalences that should be
- *                                considered supported.
- * \return                        A string containing lines of the form
- *                                "  'name' for <equivalence>". Every line
- *                                except the last is terminated with '\\n'.
- */
-
-inline std::string supported_lts_equivalences_text(
-  lts_equivalence default_equivalence = lts_eq_none,
-  const std::set<lts_equivalence> &supported = supported_lts_equivalences())
-{
-  std::vector<lts_equivalence> types(supported.begin(),supported.end());
-
-  {
-    std::vector<lts_equivalence> validtypes;
-    for (std::vector<lts_equivalence>::iterator i=types.begin(); i!=types.end(); i++)
-    {
-      if( (*i) != lts_eq_none)
-      {
-        validtypes.push_back(*i);
-      }
-    }
-    types = validtypes;
-  }
-
-  std::sort(types.begin(),types.end(),boost::bind(lts_named_cmp<lts_equivalence>,equivalence_strings,_1,_2));
-
-  std::string r;
-  for (std::vector<lts_equivalence>::iterator i=types.begin(); i!=types.end(); i++)
-  {
-    r += "  '" + equivalence_strings[*i] + "' for " + equivalence_desc_strings[*i];
-
-    if (*i == default_equivalence)
-    {
-      r += " (default)";
-    }
-
-
-    if (i+1 != types.end())
-    {
-      if (i+2 == types.end())
-      {
-        r += ", or\n";
-      }
-      else
-      {
-        r += ",\n";
-      }
-    }
-  }
-
-  return r;
-}
-
-/** \brief Gives a textual list describing supported equivalences on LTSs.
- * \param[in] supported           The equivalences that should be
- *                                considered supported.
- * \return                        A string containing lines of the form
- *                                "  'name' for <equivalence>". Every line
- *                                except the last is terminated with '\\n'.
- */
-inline std::string supported_lts_equivalences_text(const std::set<lts_equivalence> &supported)
-{
-  return supported_lts_equivalences_text(lts_eq_none,supported);
-}
-
-
-/** \brief Gives a textual list describing supported preorders on LTSs.
- * \param[in] default_preorder    The preorder that should be marked
- *                                as default (or \a lts_pre_none for no
- *                                default).
- * \param[in] supported           The preorders that should be
- *                                considered supported.
- * \return                        A string containing lines of the form
- *                                "  'name' for <preorder>". Every line
- *                                except the last is terminated with '\\n'.
- */
-inline std::string supported_lts_preorders_text(
-  lts_preorder default_preorder = lts_pre_none,
-  const std::set<lts_preorder> &supported = supported_lts_preorders())
-{
-  std::vector<lts_preorder> types(supported.begin(),supported.end());
-  std::sort(types.begin(),types.end(),boost::bind(lts_named_cmp<lts_preorder>,preorder_strings,_1,_2));
-
-  std::string r;
-  for (std::vector<lts_preorder>::iterator i=types.begin(); i!=types.end(); i++)
-  {
-    r += "  '" + preorder_strings[*i] + "' for " + preorder_desc_strings[*i];
-
-    if (*i == default_preorder)
-    {
-      r += " (default)";
-    }
-
-    if (i+1 != types.end())
-    {
-      if (i+2 == types.end())
-      {
-        r += ", or\n";
-      }
-      else
-      {
-        r += ",\n";
-      }
-    }
-  }
-
-  return r;
-}
-
-/** \brief Gives a textual list describing supported preorders on LTSs.
- * \param[in] supported           The preorders that should be
- *                                considered supported.
- * \return                        A string containing lines of the form
- *                                "  'name' for <preorder>". Every line
- *                                except the last is terminated with '\\n'.
- */
-inline std::string supported_lts_preorders_text(const std::set<lts_preorder> &supported)
-{
-  return supported_lts_preorders_text(lts_pre_none,supported);
-}
-
-
 /** \brief Applies a reduction algorithm to this LTS.
  * \param[in] eq The equivalence with respect to which the LTS will be
  * reduced.
@@ -729,16 +365,34 @@ void reduce(LTS_TYPE& l,lts_equivalence eq)
       detail::bisimulation_reduce(l,false,false);
       return;
     }
+    case lts_eq_bisim_sigref:
+    {
+      sigref<LTS_TYPE, signature_bisim<LTS_TYPE> > s(l);
+      s.run();
+      return;
+    }
     case lts_eq_branching_bisim:
     {
       detail::bisimulation_reduce(l,true,false);
       return;
     }
+    case lts_eq_branching_bisim_sigref:
+    {
+      sigref<LTS_TYPE, signature_branching_bisim<LTS_TYPE> > s(l);
+      s.run();
+      return;
+    }
     case lts_eq_divergence_preserving_branching_bisim:
     {
       detail::bisimulation_reduce(l,true,true);
       return;
     }
+    case lts_eq_divergence_preserving_branching_bisim_sigref:
+    {
+      sigref<LTS_TYPE, signature_divergence_preserving_branching_bisim<LTS_TYPE> > s(l);
+      s.run();
+      return;
+    }
     case lts_eq_sim:
     {
       // Run the partitioning algorithm on this LTS
