@@ -12,6 +12,8 @@
 #ifndef MCRL2_PBES_DETAIL_ENUMERATE_QUANTIFIERS_BUILDER_H
 #define MCRL2_PBES_DETAIL_ENUMERATE_QUANTIFIERS_BUILDER_H
 
+//#define MCRL2_ENUMERATE_QUANTIFIERS_BUILDER_DEBUG
+
 #include <numeric>
 #include <set>
 #include <utility>
@@ -541,11 +543,15 @@ struct enumerate_quantifiers_builder: public simplify_rewrite_builder<Term, Data
   /// \param phi A term
   /// \param sigma A substitution function
   /// \return The result of visiting the node
-  term_type visit_forall(const term_type& x, const variable_sequence_type& variables, const term_type& phi, SubstitutionFunction& sigma)
+  term_type visit_forall(const term_type& /* x */, const variable_sequence_type& variables, const term_type& phi, SubstitutionFunction& sigma)
   {
+#ifdef MCRL2_ENUMERATE_QUANTIFIERS_BUILDER_DEBUG
+    std::cerr << "<visit_forall>" << tr::pp(forall(variables, phi)) << std::endl;
+#endif
+    term_type result;
     if (m_enumerate_infinite_sorts)
     {
-      return quantifier_enumerator<self, DataEnumerator>(*this, m_data_enumerator).enumerate_universal_quantification(variables, phi, sigma);
+      result = quantifier_enumerator<self, DataEnumerator>(*this, m_data_enumerator).enumerate_universal_quantification(variables, phi, sigma);
     }
     else
     {
@@ -554,13 +560,17 @@ struct enumerate_quantifiers_builder: public simplify_rewrite_builder<Term, Data
       split_finite_variables(variables, m_data_enumerator.data(), finite, infinite);
       if (finite.empty())
       {
-        return x;
+        result = utilities::optimized_forall(infinite, super::visit(phi, sigma));
       }
       else
       {
-        return utilities::optimized_forall(infinite, quantifier_enumerator<self, DataEnumerator>(*this, m_data_enumerator).enumerate_universal_quantification(finite, phi, sigma));
+        result = utilities::optimized_forall_no_empty_domain(infinite, quantifier_enumerator<self, DataEnumerator>(*this, m_data_enumerator).enumerate_universal_quantification(finite, phi, sigma));
       }
     }
+#ifdef MCRL2_ENUMERATE_QUANTIFIERS_BUILDER_DEBUG
+    std::cerr << "<visit_forall_result>" << tr::pp(result) << std::endl;
+#endif
+    return result;
   }
 
   /// \brief Visit exists node
@@ -570,10 +580,10 @@ struct enumerate_quantifiers_builder: public simplify_rewrite_builder<Term, Data
   /// \param phi A term
   /// \param sigma A substitution function
   /// \return The result of visiting the node
-  term_type visit_exists(const term_type& x, const variable_sequence_type& variables, const term_type& phi, SubstitutionFunction& sigma)
+  term_type visit_exists(const term_type& /* x */, const variable_sequence_type& variables, const term_type& phi, SubstitutionFunction& sigma)
   {
 #ifdef MCRL2_ENUMERATE_QUANTIFIERS_BUILDER_DEBUG
-    std::cerr << "<visit_exists>" << tr::pp(x) << std::endl;
+    std::cerr << "<visit_exists>" << tr::pp(exists(variables, phi)) << std::endl;
 #endif
     term_type result;
     if (m_enumerate_infinite_sorts)
@@ -587,11 +597,11 @@ struct enumerate_quantifiers_builder: public simplify_rewrite_builder<Term, Data
       split_finite_variables(variables, m_data_enumerator.data(), finite, infinite);
       if (finite.empty())
       {
-        result = x;
+        result = utilities::optimized_exists(infinite, super::visit(phi, sigma));
       }
       else
       {
-        result = utilities::optimized_exists(infinite, quantifier_enumerator<self, DataEnumerator>(*this, m_data_enumerator).enumerate_existential_quantification(finite, phi, sigma));
+        result = utilities::optimized_exists_no_empty_domain(infinite, quantifier_enumerator<self, DataEnumerator>(*this, m_data_enumerator).enumerate_existential_quantification(finite, phi, sigma));
       }
     }
 #ifdef MCRL2_ENUMERATE_QUANTIFIERS_BUILDER_DEBUG
