@@ -232,7 +232,7 @@ struct simplify_rewrite_builder: public pbes_expr_builder<Term, SubstitutionFunc
   {
     typedef typename core::term_traits<data_term_type> tt;
     term_type t = super::visit(phi, sigma);
-    return utilities::optimized_forall(tt::set_intersection(variables, tr::free_variables(t)), t);
+    return utilities::optimized_forall(variables, t, true);
   }
 
   /// \brief Visit exists node
@@ -246,7 +246,7 @@ struct simplify_rewrite_builder: public pbes_expr_builder<Term, SubstitutionFunc
   {
     typedef typename core::term_traits<data_term_type> tt;
     term_type t = super::visit(phi, sigma);
-    return utilities::optimized_exists(tt::set_intersection(variables, tr::free_variables(t)), t);
+    return utilities::optimized_exists(variables, t);
   }
 
   /// \brief Visit propositional_variable node
