@@ -19,6 +19,7 @@
 #include "mcrl2/core/detail/constructors.h"
 #include "mcrl2/core/detail/soundness_checks.h"
 #include "mcrl2/core/detail/struct_core.h"
+#include "mcrl2/data/data_specification.h"
 
 namespace mcrl2
 {
@@ -81,6 +82,9 @@ class fixpoint_symbol: public atermpp::aterm_appl
     }
 };
 
+// template function overloads
+std::string pp(const fixpoint_symbol& x);
+
 } // namespace pbes_system
 
 } // namespace mcrl2
