@@ -28,6 +28,7 @@
 #include "mcrl2/pbes/pbes.h"
 #include "mcrl2/pbes/rewriter.h"
 #include "mcrl2/pbes/detail/bes_equation_limit.h"
+#include "mcrl2/pbes/detail/instantiate_global_variables.h"
 #include "mcrl2/utilities/number_postfix_generator.h"
 
 namespace mcrl2
@@ -154,7 +155,7 @@ class parity_game_generator
     /// \brief Generates a substitution function for the pbesinst rewriter.
     /// \param v A sequence of data variables
     /// \param e A sequence of data expressions
-    /// \return A sugstitution function.
+    /// \return A substitution function.
     virtual
     substitution_function make_substitution(data::variable_list v, data::data_expression_list e)
     {
@@ -177,7 +178,7 @@ class parity_game_generator
       {
         const pbes_equation& pbes_eqn = *m_pbes_equation_index[tr::name(psi)];
         substitution_function sigma = make_substitution(pbes_eqn.variable().parameters(), tr::param(psi));
-        mCRL2log(log::debug2, "parity_game_generator") << "Expanding right hand side " << print(pbes_eqn.formula()) << " into ";
+        mCRL2log(log::debug2, "parity_game_generator") << "Expanding right hand side " << print(pbes_eqn.formula()) << " into " << std::flush;
         pbes_expression result(R(pbes_eqn.formula(), sigma));
         mCRL2log(log::debug2, "parity_game_generator") << print(result) << std::endl;
         return result;
@@ -293,7 +294,7 @@ class parity_game_generator
         compute_priorities(m_pbes.equations());
 
         // Add a BES equation for the initial state.
-        propositional_variable_instantiation phi = R(m_pbes.initial_state());
+        propositional_variable_instantiation phi = get_initial_state();
         add_bes_equation(phi, m_priorities[phi.name()]);
 
         m_initialized = true;
@@ -308,7 +309,7 @@ class parity_game_generator
     /// \param p A PBES
     /// \param true_false_dependencies If true, nodes are generated for the values <tt>true</tt> and <tt>false</tt>.
     /// \param is_min_parity If true a min-parity game is produced, otherwise a max-parity game
-    parity_game_generator(pbes<>& p, bool true_false_dependencies = false, bool is_min_parity = true, data::rewriter::strategy rewrite_strategy = data::rewriter::jitty)
+    parity_game_generator(pbes<>& p, bool true_false_dependencies = false, bool is_min_parity = true, data::rewriter::strategy rewrite_strategy = data::jitty)
       :
       m_initialized(false),
       m_pbes(p),
@@ -319,7 +320,19 @@ class parity_game_generator
       R(datarv, datae),
       m_true_false_dependencies(true_false_dependencies),
       m_is_min_parity(is_min_parity)
-    {}
+    {
+      detail::instantiate_global_variables(p);
+    }
+
+    virtual ~parity_game_generator() {}
+
+    /// \brief Returns the (rewritten) initial state.
+    /// \return the initial state rewritten by R
+    virtual propositional_variable_instantiation get_initial_state()
+    {
+      propositional_variable_instantiation phi = R(m_pbes.initial_state());
+      return phi;
+    }
 
     /// \brief Returns the vertex type.
     /// \param index A positive integer
@@ -332,6 +345,16 @@ class parity_game_generator
 
       assert(index < m_bes.size());
       const pbes_expression& phi = m_bes[index].first;
+      return get_expression_operation(phi);
+    }
+
+    /// \brief Returns the vertex type.
+    /// \param phi A PBES expression
+    /// \return PGAME_AND if the expression is a conjunction,
+    /// PGAME_OR if it is a disjunction.
+    virtual
+    operation_type get_expression_operation(const pbes_expression& phi)
+    {
       if (tr::is_and(phi))
       {
         return PGAME_AND;
@@ -352,6 +375,18 @@ class parity_game_generator
       {
         return PGAME_OR;
       }
+      else if (tr::is_forall(phi))
+      {
+        return PGAME_AND;
+      }
+      else if (tr::is_exists(phi))
+      {
+        return PGAME_OR;
+      }
+      else if (tr::is_data(phi))
+      {
+        return PGAME_OR;
+      }
       throw(std::runtime_error("Error in parity_game_generator: unexpected operation " + print(phi)));
     }
 
