@@ -268,7 +268,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term has the value true. Also works for data terms
   static inline
-  bool is_true(term_type t)
+  bool is_true(const term_type& t)
   {
     return tr::is_true(t);
   }
@@ -277,7 +277,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term has the value false. Also works for data terms
   static inline
-  bool is_false(term_type t)
+  bool is_false(const term_type& t)
   {
     return tr::is_false(t);
   }
@@ -286,7 +286,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is of type and. Also works for data terms
   static inline
-  bool is_not(term_type t)
+  bool is_not(const term_type& t)
   {
     return tr::is_not(t);
   }
@@ -295,7 +295,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is of type and. Also works for data terms
   static inline
-  bool is_and(term_type t)
+  bool is_and(const term_type& t)
   {
     return tr::is_and(t);
   }
@@ -304,7 +304,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is of type or. Also works for data terms
   static inline
-  bool is_or(term_type t)
+  bool is_or(const term_type& t)
   {
     return tr::is_or(t);
   }
@@ -313,7 +313,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is an implication. Also works for data terms
   static inline
-  bool is_imp(term_type t)
+  bool is_imp(const term_type& t)
   {
     return tr::is_imp(t);
   }
@@ -322,7 +322,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is an universal quantification. Also works for data terms
   static inline
-  bool is_forall(term_type t)
+  bool is_forall(const term_type& t)
   {
     return tr::is_forall(t);
   }
@@ -331,7 +331,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is an existential quantification. Also works for data terms
   static inline
-  bool is_exists(term_type t)
+  bool is_exists(const term_type& t)
   {
     return tr::is_exists(t);
   }
@@ -340,7 +340,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is a data term
   static inline
-  bool is_data(term_type t)
+  bool is_data(const term_type& t)
   {
     return tr::is_data(t);
   }
@@ -349,7 +349,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is a propositional variable instantiation
   static inline
-  bool is_prop_var(term_type t)
+  bool is_prop_var(const term_type& t)
   {
     return tr::is_prop_var(t);
   }
@@ -358,7 +358,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return The requested argument. Partially works for data terms
   static inline
-  term_type arg(term_type t)
+  term_type arg(const term_type& t)
   {
     return tr::arg(t);
   }
@@ -367,7 +367,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return The right argument of the term. Also works for data terms
   static inline
-  term_type left(term_type t)
+  term_type left(const term_type& t)
   {
     return tr::left(t);
   }
@@ -376,16 +376,24 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return The right argument of the term. Also works for data terms
   static inline
-  term_type right(term_type t)
+  term_type right(const term_type& t)
   {
     return tr::right(t);
   }
 
+  /// \brief Returns the argument of a term of type not
+  /// \param t A term
+  static inline
+  term_type not_arg(const term_type& t)
+  {
+    return tr::not_arg(t);
+  }
+
   /// \brief Returns the quantifier variables of a quantifier expression
   /// \param t A term
   /// \return The requested argument. Doesn't work for data terms
   static inline
-  variable_sequence_type var(term_type t)
+  variable_sequence_type var(const term_type& t)
   {
     return tr::var(t);
   }
@@ -394,7 +402,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return The name of the propositional variable instantiation
   static inline
-  string_type name(term_type t)
+  string_type name(const term_type& t)
   {
     return tr::name(t);
   }
@@ -403,7 +411,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return The parameter list of the propositional variable instantiation
   static inline
-  data_term_sequence_type param(term_type t)
+  data_term_sequence_type param(const term_type& t)
   {
     return tr::param(t);
   }
@@ -421,7 +429,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return True if the term is a variable
   static inline
-  bool is_variable(term_type t)
+  bool is_variable(const term_type& t)
   {
     return tr::is_variable(t);
   }
@@ -430,7 +438,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return The free variables of a term
   static inline
-  variable_sequence_type free_variables(term_type t)
+  variable_sequence_type free_variables(const term_type& t)
   {
     return t.variables();
   }
@@ -439,7 +447,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A data term
   /// \return The converted term
   static inline
-  term_type dataterm2term(data_term_type t)
+  term_type dataterm2term(const data_term_type& t)
   {
     return term_type(t, t.variables());
   }
@@ -448,11 +456,21 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \returns The converted term
   static inline
-  data_term_type term2dataterm(term_type t)
+  data_term_type term2dataterm(const term_type& t)
   {
     return tr::term2dataterm(t);
   }
 
+  /// \brief Returns the difference of two unordered sets of variables
+  /// \param v A sequence of data variables
+  /// \param w A sequence of data variables
+  /// \return The difference of two sets.
+  static inline
+  variable_sequence_type set_intersection(const variable_sequence_type& v, const variable_sequence_type& w)
+  {
+    return term_traits<data::data_expression>::set_intersection(v, w);
+  }
+
   /// \brief Test if a term is constant
   /// \param t A term
   /// \return True if the term is constant
@@ -466,7 +484,7 @@ struct term_traits<pbes_system::pbes_expression_with_variables>
   /// \param t A term
   /// \return A pretty print representation of the term
   static inline
-  std::string pp(term_type t)
+  std::string pp(const term_type& t)
   {
     return pbes_system::pp(t) + " variables: " + data::pp(t.variables());
   }
