@@ -17,11 +17,12 @@
 #include <boost/test/minimal.hpp>
 #include <boost/algorithm/string.hpp>
 #include "mcrl2/atermpp/aterm_init.h"
-#include "mcrl2/bes/bes_gauss_elimination.h"
+#include "mcrl2/bes/gauss_elimination.h"
 #include "mcrl2/core/garbage_collection.h"
 #include "mcrl2/data/rewriter.h"
 #include "mcrl2/data/utility.h"
 #include "mcrl2/lps/linearise.h"
+#include "mcrl2/lps/detail/test_input.h"
 #include "mcrl2/pbes/bes_algorithms.h"
 #include "mcrl2/pbes/lps2pbes.h"
 #include "mcrl2/pbes/pbes.h"
@@ -110,8 +111,7 @@ std::string BES10 =
 void test_bes(std::string bes_spec, bool expected_result)
 {
   pbes_system::pbes<> p = pbes_system::txt2pbes(bes_spec);
-  size_t log_level = 2;
-  int result = pbes_system::gauss_elimination(p, log_level);
+  int result = pbes_system::gauss_elimination(p);
   switch (result)
   {
     case 0:
@@ -146,51 +146,11 @@ void test_bes_examples()
   test_bes(BES10, false);
 }
 
-const std::string ABP_SPECIFICATION =
-  "% This file contains the alternating bit protocol, as described in W.J.    \n"
-  "% Fokkink, J.F. Groote and M.A. Reniers, Modelling Reactive Systems.       \n"
-  "%                                                                          \n"
-  "% The only exception is that the domain D consists of two data elements to \n"
-  "% facilitate simulation.                                                   \n"
-  "                                                                           \n"
-  "sort                                                                       \n"
-  "  D     = struct d1 | d2;                                                  \n"
-  "  Error = struct e;                                                        \n"
-  "                                                                           \n"
-  "act                                                                        \n"
-  "  r1,s4: D;                                                                \n"
-  "  s2,r2,c2: D # Bool;                                                      \n"
-  "  s3,r3,c3: D # Bool;                                                      \n"
-  "  s3,r3,c3: Error;                                                         \n"
-  "  s5,r5,c5: Bool;                                                          \n"
-  "  s6,r6,c6: Bool;                                                          \n"
-  "  s6,r6,c6: Error;                                                         \n"
-  "  i;                                                                       \n"
-  "                                                                           \n"
-  "proc                                                                       \n"
-  "  S(b:Bool)     = sum d:D. r1(d).T(d,b);                                   \n"
-  "  T(d:D,b:Bool) = s2(d,b).(r6(b).S(!b)+(r6(!b)+r6(e)).T(d,b));             \n"
-  "                                                                           \n"
-  "  R(b:Bool)     = sum d:D. r3(d,b).s4(d).s5(b).R(!b)+                      \n"
-  "                  (sum d:D.r3(d,!b)+r3(e)).s5(!b).R(b);                    \n"
-  "                                                                           \n"
-  "  K             = sum d:D,b:Bool. r2(d,b).(i.s3(d,b)+i.s3(e)).K;           \n"
-  "                                                                           \n"
-  "  L             = sum b:Bool. r5(b).(i.s6(b)+i.s6(e)).L;                   \n"
-  "                                                                           \n"
-  "init                                                                       \n"
-  "  allow({r1,s4,c2,c3,c5,c6,i},                                             \n"
-  "    comm({r2|s2->c2, r3|s3->c3, r5|s5->c5, r6|s6->c6},                     \n"
-  "        S(true) || K || L || R(true)                                       \n"
-  "    )                                                                      \n"
-  "  );                                                                       \n"
-  ;
-
 void test_abp()
 {
   bool timed = false;
   std::string FORMULA = "[true*]<true*>true";
-  lps::specification spec = lps::linearise(ABP_SPECIFICATION);
+  lps::specification spec = lps::linearise(lps::detail::ABP_SPECIFICATION());
   state_formulas::state_formula formula = state_formulas::parse_state_formula(FORMULA, spec);
 
   pbes_system::pbes<> p = pbes_system::lps2pbes(spec, formula, timed);
@@ -216,7 +176,6 @@ void test_bes()
   using namespace bes;
 
   typedef core::term_traits<boolean_expression> tr;
-  size_t log_level = 2;
 
   boolean_variable X("X");
   boolean_variable Y("Y");
@@ -259,10 +218,10 @@ void test_bes()
   bes4.equations().push_back(e4);
   bes4.equations().push_back(e3);
 
-  BOOST_CHECK(gauss_elimination(bes1, log_level) == false);
-  BOOST_CHECK(gauss_elimination(bes2, log_level) == true);
-  BOOST_CHECK(gauss_elimination(bes3, log_level) == false);
-  BOOST_CHECK(gauss_elimination(bes4, log_level) == true);
+  BOOST_CHECK(gauss_elimination(bes1) == false);
+  BOOST_CHECK(gauss_elimination(bes2) == true);
+  BOOST_CHECK(gauss_elimination(bes3) == false);
+  BOOST_CHECK(gauss_elimination(bes4) == true);
 
   core::garbage_collect();
 }
