@@ -165,7 +165,7 @@ void test_pbes(std::string text)
   pbes<> p = txt2pbes(text);
   std::set<data::sort_expression> sorts;
   pbes_system::find_sort_expressions(p, std::inserter(sorts, sorts.end()));
-  std::cerr << "sorts: " << core::pp(data::sort_expression_list(sorts.begin(), sorts.end())) << std::endl;
+  std::cerr << "sorts: " << data::pp(data::sort_expression_list(sorts.begin(), sorts.end())) << std::endl;
   core::garbage_collect();
 }
 
