@@ -18,6 +18,7 @@
 #include "mcrl2/core/detail/struct_core.h"
 #include "mcrl2/core/detail/constructors.h"
 #include "mcrl2/core/detail/soundness_checks.h"
+#include "mcrl2/data/data_specification.h"
 
 namespace mcrl2
 {
@@ -52,14 +53,16 @@ class action_name_multiset: public atermpp::aterm_appl
     /// \return The names of the multi-action
     core::identifier_string_list names() const
     {
-      using namespace atermpp;
-      return list_arg1(*this);
+      return atermpp::list_arg1(*this);
     }
 };
 
 /// \brief Read-only singly linked list of action_name_multiset expressions
 typedef atermpp::term_list<action_name_multiset> action_name_multiset_list;
 
+// template function overloads
+std::string pp(const action_name_multiset& x);
+
 } // namespace process
 
 } // namespace mcrl2
