@@ -12,6 +12,8 @@
 #ifndef MCRL2_PROCESS_PARSE_H
 #define MCRL2_PROCESS_PARSE_H
 
+//#define MCRL2_NEW_ALPHABET_REDUCE
+
 #include <iostream>
 #include <string>
 #include <sstream>
@@ -22,6 +24,9 @@
 #include "mcrl2/process/process_specification.h"
 #include "mcrl2/process/typecheck.h"
 #include "mcrl2/process/alphabet_reduction.h"
+#ifdef MCRL2_NEW_ALPHABET_REDUCE
+#include "mcrl2/process/alphabet.h"
+#endif
 
 namespace mcrl2
 {
@@ -55,26 +60,12 @@ struct process_actions: public lps::action_actions
     return parse_MultActIdList(node.child(1));
   }
 
-  core::identifier_string parse_CommExprRhs(const core::parse_node& node)
-  {
-    // TODO: get rid of this 'nil'
-    core::identifier_string result = core::detail::gsMakeNil();
-    if (node)
-    {
-      if (symbol_name(node.child(1).child(0)) == "Id")
-      {
-        result = parse_Id(node.child(1).child(0));
-      }
-    }
-    return result;
-  }
-
   process::communication_expression parse_CommExpr(const core::parse_node& node)
   {
     core::identifier_string id = parse_Id(node.child(0));
     core::identifier_string_list ids = parse_IdList(node.child(2));
     action_name_multiset lhs(atermpp::push_front(ids, id));
-    core::identifier_string rhs = parse_CommExprRhs(node.child(3).child(0));
+    core::identifier_string rhs = parse_Id(node.child(4));
     return process::communication_expression(lhs, rhs);
   }
 
@@ -103,6 +94,21 @@ struct process_actions: public lps::action_actions
     return parse_RenExprList(node.child(1));
   }
 
+  process::process_expression parse_IfThen(const core::parse_node& node)
+  {
+    return parse_ProcExprNoIf(node.child(1));
+  }
+
+  bool is_proc_expr_if_then(const core::parse_node& node) const
+  {
+    return (symbol_name(node).find("ProcExpr") == 0) && (node.child_count() == 2) && (symbol_name(node.child(0)) == "DataExprUnit") && (symbol_name(node.child(1)) == "->");
+  }
+
+  bool is_proc_expr_if_then_else(const core::parse_node& node) const
+  {
+    return (symbol_name(node).find("ProcExpr") == 0) && (node.child_count() == 2) && (symbol_name(node.child(0)) == "DataExprUnit") && (symbol_name(node.child(1)) == "IfThen");
+  }
+
   // TODO: get rid of the gsMakeIdAssignment call
   process::process_expression parse_ProcExpr(const core::parse_node& node)
   {
@@ -123,9 +129,9 @@ struct process_actions: public lps::action_actions
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "ProcExpr") && (node.child(1).string() == "<<") && (symbol_name(node.child(2)) == "ProcExpr")) { return bounded_init(parse_ProcExpr(node.child(0)), parse_ProcExpr(node.child(2))); }
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "ProcExpr") && (node.child(1).string() == "@") && (symbol_name(node.child(2)) == "DataExprUnit")) { return at(parse_ProcExpr(node.child(0)), parse_DataExprUnit(node.child(2))); }
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "ProcExpr") && (node.child(1).string() == "|") && (symbol_name(node.child(2)) == "ProcExpr")) { return sync(parse_ProcExpr(node.child(0)), parse_ProcExpr(node.child(2))); }
-    else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "DataExprUnit") && (symbol_name(node.child(1)) == "->") && (symbol_name(node.child(2)) == "ProcExpr")) { return if_then(parse_DataExprUnit(node.child(0)), parse_ProcExpr(node.child(2))); }
-    else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "DataExprUnit") && (symbol_name(node.child(1)) == "IfThen") && (symbol_name(node.child(2)) == "ProcExpr")) { return if_then_else(parse_DataExprUnit(node.child(0)), parse_ProcExprNoIf(node.child(1).child(1)), parse_ProcExpr(node.child(2))); }
     else if ((node.child_count() == 4) && (symbol_name(node.child(0)) == "sum") && (symbol_name(node.child(1)) == "VarsDeclList") && (symbol_name(node.child(2)) == ".") && (symbol_name(node.child(3)) == "ProcExpr")) { return sum(parse_VarsDeclList(node.child(1)), parse_ProcExpr(node.child(3))); }
+    else if ((node.child_count() == 2) && is_proc_expr_if_then(node.child(0)) && (symbol_name(node.child(1)) == "ProcExpr")) { return if_then(parse_DataExprUnit(node.child(0).child(0)), parse_ProcExpr(node.child(1))); }
+    else if ((node.child_count() == 2) && is_proc_expr_if_then_else(node.child(0)) && (symbol_name(node.child(1)) == "ProcExpr")) { return if_then_else(parse_DataExprUnit(node.child(0).child(0)), parse_IfThen(node.child(0).child(1)), parse_ProcExpr(node.child(1))); }
     report_unexpected_node(node);
     return process::process_expression();
   }
@@ -150,8 +156,8 @@ struct process_actions: public lps::action_actions
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "ProcExprNoIf") && (node.child(1).string() == "<<") && (symbol_name(node.child(2)) == "ProcExprNoIf")) { return bounded_init(parse_ProcExprNoIf(node.child(0)), parse_ProcExprNoIf(node.child(2))); }
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "ProcExprNoIf") && (node.child(1).string() == "@") && (symbol_name(node.child(2)) == "DataExprUnit")) { return at(parse_ProcExprNoIf(node.child(0)), parse_DataExprUnit(node.child(2))); }
     else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "ProcExprNoIf") && (node.child(1).string() == "|") && (symbol_name(node.child(2)) == "ProcExprNoIf")) { return sync(parse_ProcExprNoIf(node.child(0)), parse_ProcExprNoIf(node.child(2))); }
-    else if ((node.child_count() == 3) && (symbol_name(node.child(0)) == "DataExprUnit") && (symbol_name(node.child(1)) == "IfThen") && (symbol_name(node.child(2)) == "ProcExprNoIf")) { return if_then_else(parse_DataExprUnit(node.child(0)), parse_ProcExprNoIf(node.child(1).child(1)), parse_ProcExprNoIf(node.child(2))); }
     else if ((node.child_count() == 4) && (symbol_name(node.child(0)) == "sum") && (symbol_name(node.child(1)) == "VarsDeclList") && (symbol_name(node.child(2)) == ".") && (symbol_name(node.child(3)) == "ProcExprNoIf")) { return sum(parse_VarsDeclList(node.child(1)), parse_ProcExprNoIf(node.child(3))); }
+    else if ((node.child_count() == 2) && is_proc_expr_if_then_else(node.child(0)) && (symbol_name(node.child(1)) == "ProcExprNoIf")) { return if_then_else(parse_DataExprUnit(node.child(0).child(0)), parse_IfThen(node.child(0).child(1)), parse_ProcExprNoIf(node.child(1))); }
     report_unexpected_node(node);
     return process::process_expression();
   }
@@ -263,9 +269,12 @@ void complete_process_specification(process_specification& x, bool alpha_reduce
   type_check(x);
   if (alpha_reduce)
   {
-    // apply_alphabet_reduction(x);
+#ifdef MCRL2_NEW_ALPHABET_REDUCE
+    alphabet_reduce(x);
+#else
     alphabet_reduction reduce;
     reduce(x);
+#endif
   }
   process::translate_user_notation(x);
   process::normalize_sorts(x, x.data());
@@ -301,8 +310,8 @@ process_specification parse_process_specification(const std::string& spec_string
 /// \param[in] proc_decl A process declaration ("proc P(n: Nat);").
 inline
 process_expression parse_process_expression(const std::string& text,
-    const std::string& data_decl,
-    const std::string& proc_decl
+                                            const std::string& data_decl,
+                                            const std::string& proc_decl
                                            )
 {
   std::string proc_text = utilities::regex_replace(";", " = delta;", proc_decl);
