@@ -27,6 +27,7 @@
 #include "mcrl2/atermpp/vector.h"
 #include "mcrl2/core/print.h"
 #include "mcrl2/core/detail/struct_core.h"
+#include "mcrl2/core/detail/construction_utility.h"
 #include "mcrl2/utilities/logger.h"
 #include "mcrl2/lps/action_parse.h"
 #include "mcrl2/lps/state.h"
@@ -91,12 +92,16 @@ class Trace
     atermpp::vector < mcrl2::lps::multi_action > actions;
     size_t pos; // Invariant: pos <= actions.size().
 
-    AFun trace_pair;
-    int trace_pair_set;
     mcrl2::data::data_specification m_spec;
     lps::action_label_list m_act_decls;
     bool m_data_specification_and_act_decls_are_defined;
 
+    atermpp::function_symbol const& trace_pair() const
+    {
+      static atermpp::function_symbol trace_pair = core::detail::initialise_static_expression(trace_pair, atermpp::function_symbol("pair",2,false));
+      return trace_pair;
+    }
+
 #define TRACE_MCRL2_MARKER "mCRL2Trace"
 #define TRACE_MCRL2_MARKER_SIZE 10
 #define TRACE_MCRL2_VERSION "\x01\x00"
@@ -109,20 +114,18 @@ class Trace
     /// \details The current position
     /// and length of trace are set to 0. 
     Trace()
-      : trace_pair_set(0),
-        m_data_specification_and_act_decls_are_defined(false)
+      : m_data_specification_and_act_decls_are_defined(false)
     {
       init();
     }
-    
+
     /// \brief Constructor for an empty trace.
     /// \details The current position
     /// and length of trace are set to 0. 
     /// \param[in] spec The data specification that is used when parsing multi actions.
     /// \param[in] act_decls An action label list with action declarations that is used to parse multi actions.
     Trace(const mcrl2::data::data_specification &spec, const mcrl2::lps::action_label_list &act_decls)
-      : trace_pair_set(0),
-        m_spec(spec),
+      : m_spec(spec),
         m_act_decls(act_decls),
         m_data_specification_and_act_decls_are_defined(true)
     {
@@ -137,8 +140,7 @@ class Trace
     /// \param[in] tf The format in which the trace was stored. Default: '''tfUnknown'''.
     /// \exception mcrl2::runtime_error message in case of failure
     Trace(std::istream& is, TraceFormat tf = tfUnknown)
-      : trace_pair_set(0),
-        m_data_specification_and_act_decls_are_defined(false)
+      : m_data_specification_and_act_decls_are_defined(false)
     {
       init();
       try
@@ -147,7 +149,6 @@ class Trace
       }
       catch (...)
       {
-        cleanup();
         throw;
       }
     }
@@ -164,8 +165,7 @@ class Trace
           const mcrl2::data::data_specification &spec, 
           const mcrl2::lps::action_label_list &act_decls, 
           TraceFormat tf = tfUnknown)
-      : trace_pair_set(0),
-        m_spec(spec),
+      : m_spec(spec),
         m_act_decls(act_decls),
         m_data_specification_and_act_decls_are_defined(true)
     {
@@ -176,7 +176,6 @@ class Trace
       }
       catch (...)
       {
-        cleanup();
         throw;
       }
     }
@@ -188,8 +187,7 @@ class Trace
     /// \param[in] tf The format in which the trace was stored. Default: '''tfUnknown'''.
     /// \exception mcrl2::runtime_error message in case of failure
     Trace(std::string const& filename, TraceFormat tf = tfUnknown)
-      : trace_pair_set(0),
-        m_data_specification_and_act_decls_are_defined(false)
+      : m_data_specification_and_act_decls_are_defined(false)
     {
       init();
       try
@@ -198,7 +196,6 @@ class Trace
       }
       catch (...)
       {
-        cleanup();
         throw;
       }
     }
@@ -213,8 +210,7 @@ class Trace
           const mcrl2::data::data_specification &spec, 
           const mcrl2::lps::action_label_list &act_decls,
           TraceFormat tf = tfUnknown)
-      : trace_pair_set(0),
-        m_spec(spec),
+      : m_spec(spec),
         m_act_decls(act_decls),
         m_data_specification_and_act_decls_are_defined(true)
     {
@@ -225,18 +221,10 @@ class Trace
       }
       catch (...)
       {
-        cleanup();
         throw;
       }
     }
 
-    /// \brief Destructor for the trace.
-    /// \details This destructor frees all the associated memory of the trace.
-    ~Trace()
-    {
-      cleanup();
-    }
-
     bool operator <(const Trace& t) const
     {
       return ((states<t.states) ||
@@ -370,26 +358,6 @@ class Trace
       return actions[pos];
     }
     
-    /// \brief Get the outgoing action from the current position in the trace and
-    ///  move to the next position.
-    /// \details This routine returns the action at the current position of the
-    /// trace and moves to the next position in the trace. When the current position
-    /// is at the end of the trace, nothing happens and the default mcrl2::lps::multi_action() is returned.
-    /// \return An action_list representing the action at the current position of the
-    /// trace. This is the default multi_action when at the end of the trace.
-    mcrl2::lps::multi_action nextAction()
-    {
-      assert(actions.size()+1 >= states.size() && pos <=actions.size());
-
-      if (pos < actions.size())
-      {
-        pos++;
-        return actions[pos-1];
-      }
-      return mcrl2::lps::multi_action();
-    } 
-
-
     /// \brief Get the time of the current state in the trace.
     /// \details This is the time at which
     /// the last action occurred (if any).
@@ -590,36 +558,20 @@ class Trace
 
     bool isTimedMAct(ATermAppl t)
     {
-      return ATgetType(t)==AT_APPL && ATgetAFun(t)==trace_pair;
+      return ATgetType(t)==AT_APPL && ATgetAFun(t)==trace_pair();
     }
 
     ATermAppl makeTimedMAct(const mcrl2::lps::multi_action &ma)
     {
-      return ATmakeAppl2(trace_pair,(ATerm)(ATermList)ma.actions(), (ATerm)(ATermAppl)ma.time());
+      return ATmakeAppl2(trace_pair(),(ATerm)(ATermList)ma.actions(), (ATerm)(ATermAppl)ma.time());
     }
 
     void init()
     {
-      if (trace_pair_set == 0)
-      {
-        trace_pair = ATmakeAFun("pair",2,false);
-        ATprotectAFun(trace_pair);
-      }
-      trace_pair_set++;
-
       pos = 0;
       truncate(); // Take care that pos 0 exists.
     }
 
-    void cleanup()
-    {
-      trace_pair_set--;
-      if (trace_pair_set == 0)
-      {
-        ATunprotectAFun(trace_pair);
-      }
-    }
-
     TraceFormat detectFormat(std::istream& is)
     {
       char buf[TRACE_MCRL2_MARKER_SIZE];
@@ -787,12 +739,7 @@ class Trace
         i--;
         if (i<actions.size())
         {
-          assert(actions.size()>i && actions[i]!=mcrl2::lps::multi_action());
-          /* if (!core::detail::gsIsMultAct(actions[i]) && !error_shown)
-          {
-            mCRL2log(log::error) << "saving trace that is not in mCRL2 format to a mCRL2 trace format" << std::endl;
-            error_shown = true;
-          } */
+          assert(actions.size()>i);
           trace = ATinsert(trace,(ATerm) makeTimedMAct(actions[i]));
         }
         if (states.size()>i)
