@@ -43,7 +43,7 @@ inline void string_to_strategy_test(std::string const& strategy)
 template < bool b >
 inline void string_to_prover_type_test(std::string const& prover_type)
 {
-  string_to_type_test< mcrl2::data::detail::SMT_Solver_Type, b >(prover_type);
+  string_to_type_test< mcrl2::data::detail::smt_solver_type, b >(prover_type);
 }
 
 BOOST_AUTO_TEST_CASE(border_invalid)
@@ -156,11 +156,6 @@ BOOST_AUTO_TEST_CASE(rewriting_options)
 #if defined(MCRL2_JITTYC_AVAILABLE)
   string_to_strategy_test< true >("jittyc");
 #endif
-  string_to_strategy_test< false >("inner");
-  string_to_strategy_test< false >("innerp");
-  string_to_strategy_test< false >("innerc");
-  string_to_strategy_test< false >("innera");
-  string_to_strategy_test< false >("ainner");
 
   // Test rewriting options (-r and --rewrite with a mandatory argument)
   tool().add_options(test_interface);
