@@ -11,6 +11,9 @@
 #ifndef CLUSTER_H
 #define CLUSTER_H
 
+#include <QtCore>
+#include <QtGui>
+
 #include <cstddef>
 #include <vector>
 #include "attribute.h"
@@ -28,44 +31,45 @@ class Cluster
     virtual ~Cluster();
 
     // -- set functions ---------------------------------------------
-    void setCoord(const std::vector< size_t > &crd);
-    void setIndex(const size_t& idx);
-    void setParent(Cluster* p);
-    void addChild(Cluster* c);
-    void setChildren(const std::vector< Cluster* > &c);
-    void addNode(Node* n);
-    void setNodes(const std::vector< Node* > &n);
+    void setCoord(const std::vector< size_t > &crd) { coord = crd; }
+    void setIndex(const size_t& idx) { index = idx; }
+    void setParent(Cluster* p) { parent = p; }
+    void addChild(Cluster* c) { children.push_back(c); }
+    void setChildren(const std::vector< Cluster* > &c) { clearChildren(); children = c; }
+    void addNode(Node* n) { nodes.push_back(n); }
+    void setNodes(const std::vector< Node* > &n) { clearNodes(); nodes = n; }
 
-    void setAttribute(Attribute* attr);
-    void setAttrValIdx(const size_t& idx);
+    void setAttribute(Attribute* attr) { attribute = attr; }
+    void setAttrValIdx(const size_t& idx) { attrValIdx = idx; }
+
+    void addInBundle(Bundle* b) { inBundles.push_back(b); }
+    void setInBundles(const std::vector< Bundle* > b) { clearInBundles(); inBundles = b; }
+    void addOutBundle(Bundle* b) { outBundles.push_back(b); }
+    void setOutBundles(const std::vector< Bundle* > b) { clearOutBundles(); outBundles = b; }
 
-    void addInBundle(Bundle* b);
-    void setInBundles(const std::vector< Bundle* > b);
-    void addOutBundle(Bundle* b);
-    void setOutBundles(const std::vector< Bundle* > b);
 
     // -- get functions ---------------------------------------------
-    size_t getSizeCoord();
+    size_t getSizeCoord() { return coord.size(); }
     size_t getCoord(const size_t& idx);
-    void getCoord(std::vector< size_t > &crd);
-    size_t getIndex();
-    Cluster* getParent();
-    size_t getSizeChildren();
+    void getCoord(std::vector< size_t > &crd) { crd = coord; }
+    size_t getIndex() { return index; }
+    Cluster* getParent() { return parent; }
+    size_t getSizeChildren() { return children.size(); }
     Cluster* getChild(const size_t& idx);
-    size_t getSizeNodes();
+    size_t getSizeNodes() { return nodes.size(); }
     Node* getNode(const size_t& idx);
     size_t getSizeDescNodes();
 
-    Attribute* getAttribute();
-    size_t getAttrValIdx();
+    Attribute* getAttribute() { return attribute; }
+    size_t getAttrValIdx() { return attrValIdx; }
 
-    size_t getSizeInBundles();
+    size_t getSizeInBundles() { return inBundles.size(); }
     Bundle* getInBundle(const size_t& idx);
-    size_t getSizeOutBundles();
+    size_t getSizeOutBundles() { return outBundles.size(); }
     Bundle* getOutBundle(const size_t& idx);
 
     // -- clear functions -------------------------------------------
-    void clearParent();
+    void clearParent() { parent = 0; }
     void clearChildren();
     void clearNodes();
     void clearAttribute();
