@@ -8,8 +8,6 @@
 //
 /// \file ./corrlplot.cpp
 
-#include "wx.hpp" // precompiled headers
-
 #include "corrlplot.h"
 
 using namespace std;
@@ -17,75 +15,38 @@ using namespace std;
 // -- constructors and destructor -----------------------------------
 
 
-// ----------------------------
 CorrlPlot::CorrlPlot(
-  Mediator* m,
+  QWidget *parent,
   Graph* g,
-  GLCanvas* c)
-  : Visualizer(m, g, c)
-// ----------------------------
+  int attributeIndex1,
+  int attributeIndex2):
+  Visualizer(parent, g)
 {
   minRadHintPx =  5;
   maxRadHintPx = 25;
 
-  diagram         = NULL;
+  diagram         = 0;
   showDgrm        = false;
   attrValIdx1Dgrm = NON_EXISTING;
   attrValIdx2Dgrm = NON_EXISTING;
-}
 
+  attribute1 = m_graph->getAttribute(attributeIndex1);
+  attribute2 = m_graph->getAttribute(attributeIndex2);
+  connect(attribute1, SIGNAL(deleted()), this, SLOT(close()));
+  connect(attribute2, SIGNAL(deleted()), this, SLOT(close()));
 
-// --------------------
-CorrlPlot::~CorrlPlot()
-// --------------------
-{
-  clearValues();
-  diagram = NULL;
+  m_graph->calcAttrCorrl(attributeIndex1, attributeIndex2, mapXToY, number);
+  initLabels();
+  calcMaxNumber();
+  calcPositions();
+
+  setMouseTracking(true);
 }
 
 
 // -- set data functions --------------------------------------------
 
-
-// -------------------------------------
-void CorrlPlot::setValues(
-  const size_t& idx1,
-  const size_t& idx2,
-  const vector< vector< size_t > > &mapXY,
-  const vector< vector< int > > &num)
-// -------------------------------------
-{
-  clearValues();
-  attrIdx1 = idx1;
-  attrIdx2 = idx2;
-  mapXToY = mapXY;
-  number  = num;
-  initLabels();
-  calcMaxNumber();
-  calcPositions();
-}
-
-
-// --------------------------
-void CorrlPlot::clearValues()
-// --------------------------
-{
-  attrIdx1  = NON_EXISTING;
-  attrIdx2  = NON_EXISTING;
-  maxNumber = 0;
-  maxNumX.clear();
-  sumMaxNumX = 0;
-  maxNumY.clear();
-  sumMaxNumY = 0;
-  mapXToY.clear();
-  number.clear();
-  clearPositions();
-}
-
-
-// ----------------------------------------
 void CorrlPlot::setDiagram(Diagram* dgrm)
-// ----------------------------------------
 {
   diagram = dgrm;
 }
@@ -94,9 +55,7 @@ void CorrlPlot::setDiagram(Diagram* dgrm)
 // -- visualization functions  --------------------------------------
 
 
-// --------------------------------------------------
 void CorrlPlot::visualize(const bool& inSelectMode)
-// --------------------------------------------------
 {
   // have textures been generated
   if (texCharOK != true)
@@ -147,78 +106,66 @@ void CorrlPlot::visualize(const bool& inSelectMode)
 }
 
 
-// --------------------------
 void CorrlPlot::drawAxes(
   const bool& inSelectMode,
   const string& /*xLbl*/,
   const string& /*yLbl*/)
-// --------------------------
 {
-  // get size of sides
-  double w, h;
-  canvas->getSize(w, h);
-  // get size of 1 pixel
-  double pix = canvas->getPixelSize();
+  QSizeF size = worldSize();
+  double pix = pixelSize();
 
   // calc size of bounding box
-  double xLft = -0.5*w+20*pix;
-  double xRgt =  0.5*w-10*pix;
-  double yTop =  0.5*h-10*pix;
-  double yBot = -0.5*h+20*pix;
+  double xLft = -0.5*size.width()+20*pix;
+  double xRgt =  0.5*size.width()-10*pix;
+  double yTop =  0.5*size.height()-10*pix;
+  double yBot = -0.5*size.height()+20*pix;
 
   // rendering mode
   if (inSelectMode != true)
   {
     // draw guides
-    VisUtils::setColorLtGray();
+    VisUtils::setColor(VisUtils::lightGray);
     VisUtils::drawLine(xLft, xRgt, yTop, yTop);
     VisUtils::drawLine(xRgt, xRgt, yBot, yTop);
-    VisUtils::setColorLtGray();
+    VisUtils::setColor(VisUtils::lightGray);
     VisUtils::enableLineAntiAlias();
     VisUtils::drawLine(xLft, xRgt, yBot, yTop);
     VisUtils::disableLineAntiAlias();
 
     // x- & y-axis
-    VisUtils::setColorMdGray();
+    VisUtils::setColor(VisUtils::mediumGray);
     VisUtils::drawLine(xLft, xLft, yBot, yTop);
     VisUtils::drawLine(xLft, xRgt, yBot, yBot);
   }
 }
 
 
-// ---------------------------------------------------
 void CorrlPlot::drawLabels(const bool& /*inSelectMode*/)
-// ---------------------------------------------------
 {
-  // get size of sides
-  double w, h;
-  canvas->getSize(w, h);
-  // get size of 1 pixel
-  double pix = canvas->getPixelSize();
+  QSizeF size = worldSize();
+  double pix = pixelSize();
   // calc scaling to use
   double scaling = (12*pix)/(double)CHARHEIGHT;
 
   // color
-  VisUtils::setColorBlack();
+  VisUtils::setColor(Qt::black);
 
   if (mapXToY.size() > 0)
   {
     // x-axis label
     double x =  0.0;
-    double y = -0.5*h+9*pix;
+    double y = -0.5*size.height()+9*pix;
     VisUtils::drawLabelCenter(texCharId, x, y, scaling, xLabel);
 
     // y-axis labels
-    x = -0.5*w+9*pix;
+    x = -0.5*size.width()+9*pix;
     y =  0;
     VisUtils::drawLabelVertCenter(texCharId, x, y, scaling, yLabel);
   }
 }
 
 
-// -------------------------------------------------
 void CorrlPlot::drawPlot(const bool& inSelectMode)
-// -------------------------------------------------
 {
   // selection mode
   if (inSelectMode == true)
@@ -243,7 +190,7 @@ void CorrlPlot::drawPlot(const bool& inSelectMode)
   // rendering mode
   else
   {
-    double pix   = canvas->getPixelSize();
+    double pix   = pixelSize();
 
     for (size_t i = 0; i < positions.size(); ++i)
     {
@@ -252,12 +199,8 @@ void CorrlPlot::drawPlot(const bool& inSelectMode)
         double x   = positions[i][j].x;
         double y   = positions[i][j].y;
         double rad = radii[i][j];
-        ColorRGB col;
 
-        VisUtils::mapColorCoolGreen(col);
-        col.a = 0.35;
-
-        VisUtils::setColor(col);
+        VisUtils::setColor(VisUtils::coolGreen, 0.35);
 
         VisUtils::enableBlending();
         //VisUtils::fillCirc( x, y, rad, 21);
@@ -267,14 +210,12 @@ void CorrlPlot::drawPlot(const bool& inSelectMode)
         VisUtils::enableLineAntiAlias();
         //VisUtils::drawCirc( x, y, rad, 21);
         VisUtils::drawEllipse(x, y, rad, rad, 21);
-        VisUtils::mapColorBlack(col);
-        col.a = 0.1;
-        VisUtils::setColor(col);
+        VisUtils::setColor(Qt::black, 0.1);
         //VisUtils::drawCirc( x, y, rad, 21);
         VisUtils::drawEllipse(x, y, rad, rad, 21);
         VisUtils::disableLineAntiAlias();
 
-        VisUtils::setColorBlack();
+        VisUtils::setColor(Qt::black);
         VisUtils::fillRect(x-pix, x+pix, y+pix, y-pix);
       }
     }
@@ -282,16 +223,14 @@ void CorrlPlot::drawPlot(const bool& inSelectMode)
 }
 
 
-// ----------------------------------------------------
 void CorrlPlot::drawDiagram(const bool& inSelectMode)
-// ----------------------------------------------------
 {
-  double pix = canvas->getPixelSize();
+  double pix = pixelSize();
   double scaleTxt = ((12*pix)/(double)CHARHEIGHT)/scaleDgrm;
 
   vector< Attribute* > attrs;
-  attrs.push_back(graph->getAttribute(attrIdx1));
-  attrs.push_back(graph->getAttribute(attrIdx2));
+  attrs.push_back(attribute1);
+  attrs.push_back(attribute2);
 
   vector< double > vals;
   vals.push_back(attrValIdx1Dgrm);
@@ -302,7 +241,7 @@ void CorrlPlot::drawDiagram(const bool& inSelectMode)
   glScalef(scaleDgrm, scaleDgrm, scaleDgrm);
 
   // drop shadow
-  VisUtils::setColorMdGray();
+  VisUtils::setColor(VisUtils::mediumGray);
   VisUtils::fillRect(
     -1.0 + 4.0*pix/scaleDgrm,
     1.0 + 4.0*pix/scaleDgrm,
@@ -311,11 +250,11 @@ void CorrlPlot::drawDiagram(const bool& inSelectMode)
   // diagram
   diagram->visualize(
     inSelectMode,
-    canvas,
+    pixelSize(),
     attrs,
     vals);
 
-  VisUtils::setColorBlack();
+  VisUtils::setColor(Qt::black);
   VisUtils::drawLabelRight(texCharId, -0.98, 1.1, scaleTxt, msgDgrm);
 
   glPopMatrix();
@@ -325,57 +264,28 @@ void CorrlPlot::drawDiagram(const bool& inSelectMode)
 // -- input event handlers ------------------------------------------
 
 
-// ------------------------------------
-void CorrlPlot::handleMouseMotionEvent(
-  const int& x,
-  const int& y)
-// ------------------------------------
+void CorrlPlot::handleMouseEvent(QMouseEvent* e)
 {
-  Visualizer::handleMouseMotionEvent(x, y);
+  Visualizer::handleMouseEvent(e);
 
   // redraw in select mode
-  visualize(true);
+  updateGL(true);
   // redraw in render mode
-  visualize(false);
+  updateGL();
 }
 
-/*
-// ------------------------------------
-void CorrlPlot::handleMouseEnterEvent()
-// ------------------------------------
-{}
-*/
-/*
-// ------------------------------------
-void CorrlPlot::handleMouseLeaveEvent()
-// ------------------------------------
-{}
-*/
-
 
 // -- utility data functions ----------------------------------------
 
 
-// -------------------------
 void CorrlPlot::initLabels()
-// -------------------------
 {
-  if (attrIdx1 != NON_EXISTING && attrIdx2 != NON_EXISTING)
-  {
-    xLabel = graph->getAttribute(attrIdx1)->getName();
-    yLabel = graph->getAttribute(attrIdx2)->getName();
-  }
-  else
-  {
-    xLabel = "";
-    yLabel = "";
-  }
+  xLabel = attribute1->name().toStdString();
+  yLabel = attribute2->name().toStdString();
 }
 
 
-// ----------------------------
 void CorrlPlot::calcMaxNumber()
-// ----------------------------
 {
   // init max number & totals
   sumMaxNumX = 0;
@@ -383,23 +293,16 @@ void CorrlPlot::calcMaxNumber()
   maxNumber  = 0;
 
   // init max row & col numbers
-  if (attrIdx1 != NON_EXISTING && attrIdx2 != NON_EXISTING)
+  size_t sizeX = attribute1->getSizeCurValues();
+  size_t sizeY = attribute2->getSizeCurValues();
+  for (size_t i = 0; i < sizeX; ++i)
   {
-    size_t sizeX = graph->getAttribute(attrIdx1)->getSizeCurValues();
-    size_t sizeY = graph->getAttribute(attrIdx2)->getSizeCurValues();
-    {
-      for (size_t i = 0; i < sizeX; ++i)
-      {
-        maxNumX.push_back(0);
-      }
-    }
+    maxNumX.push_back(0);
+  }
 
-    {
-      for (size_t i = 0; i < sizeY; ++i)
-      {
-        maxNumY.push_back(0);
-      }
-    }
+  for (size_t i = 0; i < sizeY; ++i)
+  {
+    maxNumY.push_back(0);
   }
 
   // calc max
@@ -444,89 +347,41 @@ void CorrlPlot::calcMaxNumber()
 
 // ***
 /*
-// --------------------
 void CorrlPlot::clear()
-// --------------------
 {
     VisUtils::clear( clearColor );
 }
 */
 
-// -------------------------------
 void CorrlPlot::setScalingTransf()
-// -------------------------------
 {
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
-  double f = canvas->getScaleFactor();
-  glScalef(f, f, f);
-  glTranslatef(
-    canvas->getXTranslation(),
-    canvas->getYTranslation(),
-    0.0);
 }
 
 
-// --------------------------
 void CorrlPlot::displTooltip(
   const int& xIdx,
   const int& yIdx)
-// --------------------------
 {
   msgDgrm.clear();
-  /*
-  // x-axis label
-  msgDgrm.append( xLabel );
-  msgDgrm.append( ": " );
-  msgDgrm.append( graph->getAttribute( attrIdx1 )->getCurValue( xIdx )->getValue() );
-  msgDgrm.append( "; " );
-  // y-axis label
-  msgDgrm.append( yLabel );
-  msgDgrm.append( ": " );
-  msgDgrm.append( graph->getAttribute( attrIdx2 )->getCurValue( mapXToY[xIdx][yIdx] )->getValue() );
-  msgDgrm.append( "; " );
-  */
   // number
   msgDgrm.append(Utils::dblToStr(number[xIdx][ yIdx ]));
   msgDgrm.append(" nodes; ");
   // percentage
   msgDgrm.append(Utils::dblToStr(
-                   Utils::perc((double) number[xIdx][ yIdx ], (double) graph->getSizeNodes())));
+                   Utils::perc((double) number[xIdx][ yIdx ], (double) m_graph->getSizeNodes())));
   msgDgrm.append("%");
 
-  if (diagram == NULL)
+  if (diagram == 0)
   {
-    // show tooltip
-    canvas->showToolTip(msgDgrm);
+    setToolTip(QString::fromStdString(msgDgrm));
   }
   else
   {
-    // calc diagram position
-    double xM, yM;
-    double xD, yD;
-    canvas->getWorldCoords(xMouseCur, yMouseCur, xM, yM);
-
-    if (xM < 0)
-    {
-      xD = xM+1.0*scaleDgrm;
-    }
-    else
-    {
-      xD = xM-1.0*scaleDgrm;
-    }
-
-    if (yM < 0)
-    {
-      yD = yM+1.0*scaleDgrm;
-    }
-    else
-    {
-      yD = yM-1.0*scaleDgrm;
-    }
-
-    posDgrm.x = xD;
-    posDgrm.y = yD;
-
+    QPointF pos = worldCoordinate(m_lastMouseEvent.posF());
+    posDgrm.x = pos.x() + (pos.x() < 0 ? 1.0 : -1.0) * scaleDgrm;
+    posDgrm.y = pos.y() + (pos.x() < 0 ? 1.0 : -1.0) * scaleDgrm;
     showDgrm       = true;
     attrValIdx1Dgrm = xIdx;
     attrValIdx2Dgrm = mapXToY[xIdx][yIdx];
@@ -534,29 +389,25 @@ void CorrlPlot::displTooltip(
 }
 
 
-// ----------------------------
 void CorrlPlot::calcPositions()
-// ----------------------------
 {
   // update flag
   geomChanged = false;
 
   if (mapXToY.size() > 0)
   {
-    // get size of canvas & 1 pixel
-    double w,h;
-    canvas->getSize(w, h);
-    double pix = canvas->getPixelSize();
+    QSizeF size = worldSize();
+    double pix = pixelSize();
 
     // calc sides of bounding box
-    double xLft = -0.5*w+20*pix;
-    double xRgt =  0.5*w-10*pix;
-    double yTop =  0.5*h-10*pix;
-    double yBot = -0.5*h+20*pix;
+    double xLft = -0.5*size.width()+20*pix;
+    double xRgt =  0.5*size.width()-10*pix;
+    double yTop =  0.5*size.height()-10*pix;
+    double yBot = -0.5*size.height()+20*pix;
 
     // get number of values per axis
-    double numX = graph->getAttribute(attrIdx1)->getSizeCurValues();
-    double numY = graph->getAttribute(attrIdx2)->getSizeCurValues();
+    double numX = attribute1->getSizeCurValues();
+    double numY = attribute2->getSizeCurValues();
 
     // calc intervals per axis
     double fracX = 1.0;
@@ -576,25 +427,7 @@ void CorrlPlot::calcPositions()
     radii.clear();
 
     // calc positions
-    double maxRadius;
-    if ((0.5*fracX > maxRadHintPx*pix) &&
-        (0.5*fracY > maxRadHintPx*pix))
-    {
-      maxRadius = 0.5*Utils::minn(fracX, fracY);
-    }
-    else
-    {
-      maxRadius = maxRadHintPx*pix;
-      yTop -= (maxRadius-10*pix);
-      if (numY > 1)
-      {
-        fracY = (1.0/(double)(numY))*(yTop-yBot);
-      }
-      else
-      {
-        fracY = 1.0;
-      }
-    }
+    double maxRadius = Utils::maxx(maxRadHintPx*pix, 0.5*Utils::minn(fracX, fracY));
 
     for (size_t i = 0; i < mapXToY.size(); ++i)
     {
@@ -637,9 +470,7 @@ void CorrlPlot::calcPositions()
 // -- utility data functions ----------------------------------------
 
 
-// -----------------------------
 void CorrlPlot::clearPositions()
-// -----------------------------
 {
   positions.clear();
   radii.clear();
@@ -649,11 +480,9 @@ void CorrlPlot::clearPositions()
 // -- hit detection -------------------------------------------------
 
 
-// -------------------------
 void CorrlPlot::processHits(
   GLint hits,
   GLuint buffer[])
-// -------------------------
 {
   GLuint* ptr;
   ptr = (GLuint*) buffer;
@@ -689,11 +518,11 @@ void CorrlPlot::processHits(
   }
   else
   {
-    canvas->clearToolTip();
+    setToolTip(QString());
     showDgrm = false;
   }
 
-  ptr = NULL;
+  ptr = 0;
 }
 
 
