@@ -136,10 +136,10 @@ void DiagramEditor::visualize(const bool& inSelectMode)
 
       QRectF gridCoordinates = m_diagram->gridCoordinates();
 
-      double x1 = qMin(start.x(), gridCoordinates.right());
-      double y1 = qMin(start.y(), gridCoordinates.top());
-      double x2 = qMax(stop.x(), gridCoordinates.left());
-      double y2 = qMax(stop.y(), gridCoordinates.bottom());
+      qreal x1 = qMin(start.x(), gridCoordinates.right());
+      qreal y1 = qMin(start.y(), gridCoordinates.top());
+      qreal x2 = qMax(stop.x(), gridCoordinates.left());
+      qreal y2 = qMax(stop.y(), gridCoordinates.bottom());
 
       x1 = qMax(x1, gridCoordinates.left());
       y1 = qMax(y1, gridCoordinates.bottom());
