@@ -11,17 +11,19 @@
 #ifndef PARSER_H
 #define PARSER_H
 
+#include <QtCore>
+#include <QtGui>
+#include <QDomDocument>
+
 #include <cstddef>
 #include <fstream>
 #include <iostream>
 #include <map>
 #include <string>
 #include <vector>
-#include "colleague.h"
 #include "diagram.h"
 #include "dof.h"
 #include "graph.h"
-#include <wx/xml/xml.h>
 #include "utils.h"
 
 template <class T>
@@ -32,89 +34,72 @@ inline std::string to_string(const T& t)
   return ss.str();
 }
 
-class Mediator;
-
-class Parser : public Colleague
+class Parser : public QObject
 {
+  Q_OBJECT
+
   public:
     // -- constructors and destructor -------------------------------
-    Parser(Mediator* m);
-    virtual ~Parser();
-
-    // -- parsing functions -----------------------------------------
-    int getFileSize(const std::string& path);
+    Parser(QObject* parent = 0);
 
     // fsm files
     void parseFile(
-      const std::string& path,
+      QString filename,
       Graph* graph);
     void writeFSMFile(
-      const std::string& path,
+      QString filename,
       Graph* graph);
 
     // dgc files
     void parseAttrConfig(
-      const std::string& path,
+      QString filename,
       Graph* graph,
       std::map< size_t, size_t > &attrIdxFrTo,
       std::map< size_t, std::vector< std::string > > &attrCurDomains,
       std::map< size_t, std::map< size_t, size_t  > > &attrOrigToCurDomains);
     void writeAttrConfig(
-      const std::string& path,
+      QString filename,
       Graph* graph);
 
     // dgd files
     void parseDiagram(
-      const std::string& path,
+      QString filename,
       Graph* graph,
-      Diagram* dgrmOld,
-      Diagram* dgrmNew);
+      Diagram* diagram);
     void writeDiagram(
-      const std::string& path,
+      QString filename,
       Graph* graph,
       Diagram* diagram);
 
+  signals:
+    void started(int steps);
+    void progressed(int steps);
+
   private:
     // -- private utility functions ---------------------------------
-    // fsm files
-    void parseStateVarDescr(
-      const std::string& nextLine,
-      Graph* graph);
-    void parseStates(
-      const std::string& nextLine,
-      Graph* graph);
-    void parseTransitions(
-      const std::string& nextLine,
-      Graph* graph);
+
+    QMap<QString, QDomElement> findElements(QDomElement root, QStringList tagNames);
+    QMap<QString, QString> findStringValues(QDomElement root, QStringList tagNames);
+    QMap<QString, double> findDoubleValues(QDomElement root, QStringList tagNames);
+    QMap<QString, float> findFloatValues(QDomElement root, QStringList tagNames);
+    QMap<QString, int> findIntValues(QDomElement root, QStringList tagNames);
+
+    QDomElement appendValue(QDomDocument document, QDomElement root, QString tag, QString val);
+    QDomElement appendDOF(QDomDocument document, QDomElement root, QString name, DOF* dof);
 
     // dgc files
-    void parseAttrConfig(
-      Graph* graph,
-      std::map< size_t, size_t > &attrIdxFrTo,
-      std::map< size_t, std::vector< std::string > > &attrCurDomains,
-      std::map< size_t, std::map< size_t, size_t  > > &attrOrigToCurDomains,
-      wxXmlNode* curNode);
-    void parseAttr(
+    void parseAttribute(
       Graph* graph,
       std::map< size_t, size_t > &attrIdxFrTo,
       std::map< size_t , std::vector< std::string > > &attrCurDomains,
       std::map< size_t, std::map< size_t, size_t  > > &attrOrigToCurDomains,
-      wxXmlNode* curNode);
+      QDomNode AttributeNode);
 
     // dgd files
-    void parseDiagram(
-      Graph* graph,
-      Diagram* dgrmOld,
-      Diagram* dgrmNew,
-      wxXmlNode* curNode);
     void parseShape(
       Graph* graph,
-      Diagram* dgrmOld,
-      Diagram* dgrmNew,
-      wxXmlNode* curNode);
-
-    // -- data members ----------------------------------------------
-    std::string delims;
+      Diagram* diagram,
+      QDomNode shapeNode);
 };
 
 #endif
