@@ -22,7 +22,7 @@
 #include "mcrl2/data/utility.h"
 #include "mcrl2/data/standard_utility.h"
 #include "mcrl2/data/function_symbol.h"
-#include "mcrl2/data/fresh_variable_generator.h"
+#include "mcrl2/data/set_identifier_generator.h"
 
 namespace mcrl2
 {
@@ -162,8 +162,6 @@ class linear_inequality
     };
 
 
-    // void set_factor_for_a_variable(const variable x,const data_expression e);
-
   private:
     // The right hand sides should only contain expressions representing constant reals.
 
@@ -180,16 +178,13 @@ class linear_inequality
       bool negate=false,
       const data_expression factor=real_one())
     {
-      // std::cerr << "EXPRESSION " << pp(e) <<  " factor: " << pp(factor) << "\n";
       if (sort_real::is_minus_application(e) && application(e).arguments().size()==2)
       {
-        // std::cerr << "is_minus_application\n";
         parse_and_store_expression(application(e).left(),r,negate,factor);
         parse_and_store_expression(application(e).right(),r,!negate,factor);
       }
       else if (sort_real::is_negate_application(e) && application(e).arguments().size()==1)
       {
-        // std::cerr << "is_negate_application\n";
         parse_and_store_expression(*(application(e).arguments().begin()),r,!negate,factor);
       }
       else if (sort_real::is_plus_application(e))
@@ -236,7 +231,6 @@ class linear_inequality
       }
       else if (is_closed_real_number(rewrite_with_memory(e,r)))
       {
-        // std::cerr << "CONST EXPRESSION " << pp(e) << " FACTOR " << pp(factor) << " NEG " << negate << "\n";
         if (factor==real_one())
         {
           set_rhs(negate?rewrite_with_memory(sort_real::plus(rhs(),e),r)
@@ -338,13 +332,11 @@ class linear_inequality
                       const comparison_t cmp,
                       const rewriter& r):m_lhs(),m_comparison(cmp)
     {
-      // std::cerr << "lhs " << pp(lhs) << "  rhs " << pp(rhs) << "\n";
       m_rhs.protect();
       m_rhs=real_zero();
 
       parse_and_store_expression(lhs,r);
       parse_and_store_expression(rhs,r,true);
-      // std::cerr << "Result-: " << string(*this) << "\n";
     }
 
     lhs_t::const_iterator lhs_begin() const
@@ -521,7 +513,6 @@ class linear_inequality
       for (lhs_t::const_iterator i=m_lhs.begin();
            i!=m_lhs.end(); ++i)
       {
-        // m_lhs.find(i->first) == i
         m_lhs[i->first]=rewrite_with_memory(sort_real::divides(m_lhs[i->first],e),r);
       }
       set_rhs(rewrite_with_memory(sort_real::divides(rhs(),e),r));
@@ -556,28 +547,10 @@ class linear_inequality
 };
 
 
-//static set < size_t > linear_inequality::m_empty_spots_in_rhss;
-//static atermpp::vector < mcrl2::data::data_expression > linear_inequality::m_rhss;
-
 inline
 std::string string(const linear_inequality& l)
 {
   std::string s=l.lhs_string();
-  /* if (l.lhs_begin()==l.lhs_end())
-  { s="0";
-  }
-  for( linear_inequality::lhs_t::const_iterator i=l.lhs_begin(); i!=l.lhs_end(); ++i)
-  { s=s + (i==l.lhs_begin()?"":" + ") ;
-    if (i->second==real_one())
-    { s=s + pp(i->first);
-    }
-    else if (i->second==real_minus_one())
-    { s=s + "-" + pp(i->first);
-    }
-    else
-    { s=s + pp(i->second) + "*" + pp(i->first);
-    }
-  } */
 
   if (l.comparison()==linear_inequality::less)
   {
@@ -607,7 +580,6 @@ static data_expression init_real_zero(data_expression& real_zero)
 {
   real_zero=sort_real::real_("0");
   real_zero.protect();
-  // ATprotect(reinterpret_cast<ATerm*>(&real_zero));
   return real_zero;
 }
 
@@ -615,7 +587,6 @@ static data_expression init_real_one(data_expression& real_one)
 {
   real_one=sort_real::real_("1");
   real_one.protect();
-  // ATprotect(reinterpret_cast<ATerm*>(&real_one));
   return real_one;
 }
 
@@ -623,7 +594,6 @@ static data_expression init_real_minus_one(data_expression& real_minus_one)
 {
   real_minus_one=sort_real::real_("-1");
   real_minus_one.protect();
-  // ATprotect(reinterpret_cast<ATerm*>(&real_minus_one));
   return real_minus_one;
 }
 
@@ -645,14 +615,6 @@ inline data_expression real_minus_one()
   return real_minus_one;
 }
 
-/* inline data_expression divide(const data_expression e1,const data_expression e2)
-{ return mcrl2::data::sort_real::divides(e1,e2);
-}
-
-inline data_expression multiply(const data_expression e1,const data_expression e2)
-{ return mcrl2::data::sort_real::times(e1,e2);
-} */
-
 inline data_expression min(const data_expression e1,const data_expression e2,const rewriter& r)
 {
   if (rewrite_with_memory(less_equal(e1,e2),r)==sort_bool::true_())
@@ -731,33 +693,6 @@ inline bool is_zero(const data_expression e)
   return (e==real_zero());
 }
 
-
-/// \brief Retrieve the left hand side of a data expression
-/// \param e A data expression
-/// \pre e is a data application d(x,y) with two arguments
-/// \ret x
-
-/* inline data_expression e.left()nst data_expression e)
-{
-  assert(is_data_application(e));
-  data_expression_list arguments = static_cast<const data_application&>(e).arguments();
-  assert(arguments.size() <= 2); // Allow application to be applied on unary functions!
-  return *(arguments.begin());
-} */
-
-/// \brief Retrieve the right hand side of a data expression
-/// \param e A data expression
-/// \pre e is a data application d(x,y) with two arguments
-/// \ret y
-
-/* inline data_expression rhs_(const data_expression e)
-{
-  assert(is_data_application(e));
-  data_expression_list arguments = static_cast<const data_application&>(e).arguments();
-  assert(arguments.size() == 2);
-  return *(++arguments.begin());
-} */
-
 /// \brief Print the vector of inequalities to stderr in readable form.
 inline std::string pp_vector(const std::vector < linear_inequality > &inequalities)
 {
@@ -777,7 +712,8 @@ bool is_inconsistent(
 
 
 // Count the occurrences of variables that occur in inequalities.
-static void count_occurrences(
+inline
+void count_occurrences(
   const std::vector < linear_inequality > &inequalities,
   std::map < variable, size_t> &nr_positive_occurrences,
   std::map < variable, size_t> &nr_negative_occurrences,
@@ -831,15 +767,15 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
                      const rewriter& r)
 {
   assert(resulting_inequalities.empty());
-  if (mCRL2logEnabled(debug))
+  if (mCRL2logEnabled(log::debug))
   {
-    mCRL2log(debug) << "Starting Fourier-Motzkin elimination on " + pp_vector(inequalities_in) + " on variables ";
+    mCRL2log(log::debug) << "Starting Fourier-Motzkin elimination on " + pp_vector(inequalities_in) + " on variables ";
     for (Data_variable_iterator i=variables_begin;
          i!=variables_end; ++i)
     {
-      mCRL2log(debug) << " " << pp(*i) ;
+      mCRL2log(log::debug) << " " << pp(*i) ;
     }
-    mCRL2log(debug) << std::endl;
+    mCRL2log(log::debug) << std::endl;
   }
 
   std::vector < linear_inequality > inequalities;
@@ -852,7 +788,7 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
                       variables_end,
                       r);
 
-  // std::cerr << "Fourier-Motzkin after Gauss elimination elimination on " + pp_vector(equalities) + "\n Inequalities " +
+  // mCRL2log(debug) << "Fourier-Motzkin after Gauss elimination elimination on " + pp_vector(equalities) + "\n Inequalities " +
   //          pp_vector(inequalities) + "\n";
   // At this stage, the variables that should be eliminated only occur in
   // inequalities. Group the inequalities into positive, 0, and negative
@@ -895,7 +831,7 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
       }
     }
 
-    // std::cerr << "Best variable " << pp(best_variable) << "\n";
+    // mCRL2log(debug) << "Best variable " << pp(best_variable) << "\n";
 
     if (!found)
     {
@@ -936,10 +872,10 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
       }
     }
 
-    // std::cerr << "Positive :" << pp_vector(inequalities_with_positive_variable) << "\n";
-    // std::cerr << "Negative :" << pp_vector(inequalities_with_negative_variable) << "\n";
-    // std::cerr << "Equalities :" << pp_vector(equalities) << "\n";
-    // std::cerr << "Rest :" << pp_vector(new_inequalities) << "\n";
+    // mCRL2log(debug) << "Positive :" << pp_vector(inequalities_with_positive_variable) << "\n";
+    // mCRL2log(debug) << "Negative :" << pp_vector(inequalities_with_negative_variable) << "\n";
+    // mCRL2log(debug) << "Equalities :" << pp_vector(equalities) << "\n";
+    // mCRL2log(debug) << "Rest :" << pp_vector(new_inequalities) << "\n";
 
     // Variables are grouped, now construct new inequalities as follows:
     // Keep the zero occurrences
@@ -984,7 +920,7 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
       resulting_inequalities.push_back(*i);
     }
   }
-  mCRL2log(debug) << "Fourier-Motzkin elimination yields " << pp_vector(resulting_inequalities) << std::endl;
+  mCRL2log(log::debug) << "Fourier-Motzkin elimination yields " << pp_vector(resulting_inequalities) << std::endl;
 }
 
 
@@ -1182,7 +1118,7 @@ static void pivot_and_update(
   std::map < variable, linear_inequality::lhs_t > &working_equalities,
   const rewriter& r)
 {
-  // std::cerr << "Pivoting " << pp(xi) << "   " << pp(xj) << "\n";
+  // mCRL2log(debug) << "Pivoting " << pp(xi) << "   " << pp(xj) << "\n";
   const data_expression aij=working_equalities[xi][xj];
   const data_expression theta=rewrite_with_memory(sort_real::divides(sort_real::minus(v,beta[xi]),aij),r);
   const data_expression theta_delta_correction=rewrite_with_memory(sort_real::divides(sort_real::minus(v,beta_delta_correction[xi]),aij),r);
@@ -1191,7 +1127,7 @@ static void pivot_and_update(
   beta[xj]=rewrite_with_memory(sort_real::plus(beta[xj],theta),r);
   beta_delta_correction[xj]=rewrite_with_memory(sort_real::plus(beta_delta_correction[xj],theta_delta_correction),r);
 
-  // std::cerr << "Pivoting phase 0\n";
+  // mCRL2log(debug) << "Pivoting phase 0\n";
   for (atermpp::set < variable >::const_iterator k=basic_variables.begin();
        k!=basic_variables.end(); ++k)
   {
@@ -1203,7 +1139,7 @@ static void pivot_and_update(
     }
   }
   // Apply pivoting on variables xi and xj;
-  // std::cerr << "Pivoting phase 1\n";
+  // mCRL2log(debug) << "Pivoting phase 1\n";
   basic_variables.erase(xi);
   basic_variables.insert(xj);
 
@@ -1211,8 +1147,8 @@ static void pivot_and_update(
   expression_for_xj.erase(xj);
   expression_for_xj[xi]=real_minus_one();
   expression_for_xj.multiply(sort_real::divides(real_minus_one(),aij),r);
-  // std::cerr << "Expression for xj:" << expression_for_xj.string() << "\n";
-  // std::cerr << "Pivoting phase 2\n";
+  // mCRL2log(debug) << "Expression for xj:" << expression_for_xj.string() << "\n";
+  // mCRL2log(debug) << "Pivoting phase 2\n";
   working_equalities.erase(xi);
   for (std::map < variable, linear_inequality::lhs_t >::iterator j=working_equalities.begin();
        j!=working_equalities.end(); ++j)
@@ -1220,7 +1156,7 @@ static void pivot_and_update(
     if (j->second.count(xj)>0)
     {
       const data_expression factor=j->second[xj];
-      // std::cerr << "VAR: " << pp(j->first) << " Factor " << pp(factor) << "\n";
+      // mCRL2log(debug) << "VAR: " << pp(j->first) << " Factor " << pp(factor) << "\n";
       j->second.erase(xj);
       // We need a temporary copy of expression_for_xj as otherwise the multiply
       // below will change this expression.
@@ -1230,7 +1166,7 @@ static void pivot_and_update(
   }
   working_equalities[xj]=expression_for_xj;
 
-  // std::cerr << "Pivoting phase 3\n";
+  // mCRL2log(debug) << "Pivoting phase 3\n";
   // Calculate the values for beta and beta_delta_correction for the basic variables
   for (std::map < variable, linear_inequality::lhs_t >::const_iterator i=working_equalities.begin();
        i!=working_equalities.end() ; ++i)
@@ -1239,19 +1175,19 @@ static void pivot_and_update(
     beta_delta_correction[i->first]=i->second.evaluate(beta_delta_correction,r);
   }
 
-  // std::cerr << "End pivoting " << pp(xj) << "\n";
-  if (mCRL2logEnabled(debug))
+  // mCRL2log(debug) << "End pivoting " << pp(xj) << "\n";
+  if (mCRL2logEnabled(log::debug))
   {
     for (atermpp::map < variable,data_expression >::const_iterator i=beta.begin();
          i!=beta.end(); ++i)
     {
-      // std::cerr << "beta[" << pp(i->first) << "]= " << pp(beta[i->first]) << "+ delta* " <<
+      // mCRL2log(debug) << "beta[" << pp(i->first) << "]= " << pp(beta[i->first]) << "+ delta* " <<
       //                  pp(beta_delta_correction[i->first]) << "\n";
     }
     for (std::map < variable, linear_inequality::lhs_t >::const_iterator i=working_equalities.begin();
          i!=working_equalities.end() ; ++i)
     {
-      // std::cerr << "EQ: " << pp(i->first) << " := " << i->second.string() << "\n";
+      // mCRL2log(debug) << "EQ: " << pp(i->first) << " := " << i->second.string() << "\n";
     }
   }
 }
@@ -1283,7 +1219,7 @@ inline bool is_inconsistent(
   // First remove all equalities by Gauss elimination and make a fresh variable
   // generator.
 
-  mCRL2log(debug) << "Starting an inconsistency check on " + pp_vector(inequalities_in) << "\n";
+  mCRL2log(log::debug) << "Starting an inconsistency check on " + pp_vector(inequalities_in) << "\n";
 
   // The required data structures
   atermpp::map < variable,data_expression > lowerbounds;
@@ -1296,21 +1232,21 @@ inline bool is_inconsistent(
   atermpp::set < variable > basic_variables;
   std::map < variable, linear_inequality::lhs_t > working_equalities;
 
-  fresh_variable_generator<> fresh_variable("slack_var");
+  set_identifier_generator fresh_variable_name;
 
   for (std::vector < linear_inequality >::const_iterator i=inequalities_in.begin();
        i!=inequalities_in.end(); ++i)
   {
     if (i->is_false(r))
     {
-      mCRL2log(debug) << "Inconsistent, because linear inequalities contains an inconsistent inequality\n";
+      mCRL2log(log::debug) << "Inconsistent, because linear inequalities contains an inconsistent inequality\n";
       return true;
     }
     i->add_variables(non_basic_variables);
     for (linear_inequality::lhs_t::const_iterator j=i->lhs_begin();
          j!=i->lhs_end(); ++j)
     {
-      fresh_variable.add_identifiers(j->first.name());
+      fresh_variable_name.add_identifier(j->first.name());
     }
   }
 
@@ -1328,8 +1264,8 @@ inline bool is_inconsistent(
   non_basic_variables.clear(); // gauss_elimination has removed certain variables. So, we reconstruct the non
   // basic variables again below.
 
-  // std::cerr << "Resulting equalities " << pp_vector(equalities) << "\n";
-  // std::cerr << "Resulting inequalities " << pp_vector(inequalities) << "\n";
+  // mCRL2log(debug) << "Resulting equalities " << pp_vector(equalities) << "\n";
+  // mCRL2log(debug) << "Resulting inequalities " << pp_vector(inequalities) << "\n";
 
   // Now bring the linear equalities in the basic form described
   // in the article by Bruno Dutertre and Leonardo de Moura.
@@ -1341,7 +1277,7 @@ inline bool is_inconsistent(
   {
     if (i->is_false(r))
     {
-      mCRL2log(debug) << "Inconsistent, because linear inequalities contains an inconsistent inequality after gaus elimination\n";
+      mCRL2log(log::debug) << "Inconsistent, because linear inequalities contains an inconsistent inequality after gaus elimination\n";
       return true;
     }
     if (!i->is_true(r))  // This inequality is redundant and can be skipped.
@@ -1402,13 +1338,13 @@ inline bool is_inconsistent(
       {
         // The inequality has more than one variable at the left hand side.
         // We transform it into an equation with a new slack variable.
-        variable new_basic_variable=fresh_variable(sort_real::real_());
+        variable new_basic_variable(fresh_variable_name("slack_var"), sort_real::real_());
         basic_variables.insert(new_basic_variable);
         upperbounds[new_basic_variable]=i->rhs();
         upperbounds_delta_correction[new_basic_variable]=
           ((i->comparison()==linear_inequality::less)?real_minus_one():real_zero());
         working_equalities[new_basic_variable]=i->lhs();
-        // std::cerr << "New slack variable: " << pp(new_basic_variable) << ":=" << string(*i) << "\n";
+        // mCRL2log(debug) << "New slack variable: " << pp(new_basic_variable) << ":=" << string(*i) << "\n";
       }
     }
   }
@@ -1425,7 +1361,7 @@ inline bool is_inconsistent(
            ((upperbounds[*i]==lowerbounds[*i]) &&
             (rewrite_with_memory(less(upperbounds_delta_correction[*i],lowerbounds_delta_correction[*i]),r)==sort_bool::true_()))))
       {
-        mCRL2log(debug) << "Inconsistent, preprocessing " << pp(*i) << "\n";
+        mCRL2log(log::debug) << "Inconsistent, preprocessing " << pp(*i) << "\n";
         return true; // Inconsistent.
       }
       beta[*i]=lowerbounds[*i];
@@ -1441,7 +1377,7 @@ inline bool is_inconsistent(
       beta[*i]=real_zero();
       beta_delta_correction[*i]=real_zero();
     }
-    // std::cerr << "beta[" << pp(*i) << "]=" << pp(beta[*i])<< "+delta*" <<
+    // mCRL2log(debug) << "beta[" << pp(*i) << "]=" << pp(beta[*i])<< "+delta*" <<
     // pp(beta_delta_correction[*i]) <<"\n";
   }
 
@@ -1452,7 +1388,7 @@ inline bool is_inconsistent(
     beta[*i]=working_equalities[*i].evaluate(beta,r);
     beta_delta_correction[*i]=working_equalities[*i].
                               evaluate(beta_delta_correction,r);
-    // std::cerr << "beta[" << pp(*i) << "]=" << pp(beta[*i])<< "+delta*" <<
+    // mCRL2log(debug) << "beta[" << pp(*i) << "]=" << pp(beta[*i])<< "+delta*" <<
     //                       pp(beta_delta_correction[*i]) <<"\n";
   }
 
@@ -1470,11 +1406,11 @@ inline bool is_inconsistent(
     for (atermpp::set < variable > :: const_iterator i=basic_variables.begin() ;
          i!=basic_variables.end() ; ++i)
     {
-      // std::cerr << "Evaluate start\n";
+      // mCRL2log(debug) << "Evaluate start\n";
       assert(!found);
       data_expression value=beta[*i]; // working_equalities[*i].evaluate(beta,r);
       data_expression value_delta_correction=beta_delta_correction[*i]; // working_equalities[*i].evaluate(beta_delta_correction,r);
-      // std::cerr << "Evaluate end\n";
+      // mCRL2log(debug) << "Evaluate end\n";
       if ((upperbounds.count(*i)>0) &&
           ((rewrite_with_memory(less(upperbounds[*i],value),r)==sort_bool::true_()) ||
            ((upperbounds[*i]==value) &&
@@ -1482,7 +1418,7 @@ inline bool is_inconsistent(
       {
         // The value of variable *i does not satisfy its upperbound. This must
         // be corrected using pivoting.
-        // std::cerr << "Upperbound violation " << pp(*i) << "  bound: " << pp(upperbounds[*i]) << "\n";
+        // mCRL2log(debug) << "Upperbound violation " << pp(*i) << "  bound: " << pp(upperbounds[*i]) << "\n";
         found=true;
         xi=*i;
         lowerbound_violation=false;
@@ -1495,7 +1431,7 @@ inline bool is_inconsistent(
       {
         // The value of variable *i does not satisfy its upperbound. This must
         // be corrected using pivoting.
-        // std::cerr << "Lowerbound violation " << pp(*i) << "  bound: " << pp(lowerbounds[*i]) << "\n";
+        // mCRL2log(debug) << "Lowerbound violation " << pp(*i) << "  bound: " << pp(lowerbounds[*i]) << "\n";
         found=true;
         xi=*i;
         lowerbound_violation=true;
@@ -1505,35 +1441,35 @@ inline bool is_inconsistent(
     if (!found)
     {
       // The in_equalities are consistent. Return false.
-      if (mCRL2logEnabled(debug))
+      if (mCRL2logEnabled(log::debug))
       {
-        mCRL2log(debug) << "Consistent while pivoting\n";
+        mCRL2log(log::debug) << "Consistent while pivoting\n";
         /* for(atermpp::map < variable,data_expression >::const_iterator i=lowerbounds.begin();
                       i!=lowerbounds.end(); ++i)
         { variable v=i->first;
           if (lowerbounds.count(v)>0)
           { if (rewrite_with_memory(less(beta[v],lowerbounds[v]),r)==sort_bool::true_())
-            { std::cerr << "FOUT1\n"; exit(0);
+            { mCRL2log(debug) << "FOUT1\n"; exit(0);
             }
             if (beta[v]==lowerbounds[v])
             { if (rewrite_with_memory(less(beta_delta_correction[v],lowerbounds_delta_correction[v]),r)==sort_bool::true_())
-              { std::cerr << "FOUT2\n"; exit(0);
+              { mCRL2log(debug) << "FOUT2\n"; exit(0);
               }
             }
             else
             { if (rewrite_with_memory(less(lowerbounds[v],beta[v]),r)!=sort_bool::true_())
-              { std::cerr << "FOUT2a\n"; exit(0);
+              { mCRL2log(debug) << "FOUT2a\n"; exit(0);
               }
             }
           }
 
           if (upperbounds.count(v)>0)
           { if (rewrite_with_memory(less(upperbounds[v],beta[v]),r)==sort_bool::true_())
-            { std::cerr << "FOUT3\n"; exit(0);
+            { mCRL2log(debug) << "FOUT3\n"; exit(0);
             }
             if ((beta[v]==upperbounds[v]) &&
                 (rewrite_with_memory(less(lowerbounds_delta_correction[v],beta_delta_correction[v]),r)==sort_bool::true_()))
-            { std::cerr << "FOUT4\n"; exit(0);
+            { mCRL2log(debug) << "FOUT4\n"; exit(0);
             }
           }
         } */
@@ -1541,17 +1477,17 @@ inline bool is_inconsistent(
       return false;
     }
 
-    // std::cerr << "The smallest basic variable that does not satisfy the bounds is " << pp(xi) << "\n";
+    // mCRL2log(debug) << "The smallest basic variable that does not satisfy the bounds is " << pp(xi) << "\n";
     if (lowerbound_violation)
     {
-      // std::cerr << "Lowerbound violationdt \n";
+      // mCRL2log(debug) << "Lowerbound violationdt \n";
       // select the smallest non-basic variable with which pivoting can take place.
       bool found=false;
       const linear_inequality::lhs_t& lhs=working_equalities[xi];
       for (linear_inequality::lhs_t::const_iterator xj_it=lhs.begin(); xj_it!=lhs.end(); ++xj_it)
       {
         const variable xj=xj_it->first;
-        // std::cerr << pp(xj) << "  --  " << pp(xj_it->second) << "\n";
+        // mCRL2log(debug) << pp(xj) << "  --  " << pp(xj_it->second) << "\n";
         if ((is_positive(xj_it->second,r) &&
              ((upperbounds.count(xj)==0) ||
               ((rewrite_with_memory(less(beta[xj],upperbounds[xj]),r)==sort_bool::true_())||
@@ -1571,21 +1507,21 @@ inline bool is_inconsistent(
       if (!found)
       {
         // The inequalities are inconsistent.
-        mCRL2log(debug) << "Inconsistent while pivoting\n";
+        mCRL2log(log::debug) << "Inconsistent while pivoting\n";
         return true;
       }
 
     }
     else  // Upperbound violation.
     {
-      // std::cerr << "Upperbound violationdt \n";
+      // mCRL2log(debug) << "Upperbound violationdt \n";
       // select the smallest non-basic variable with which pivoting can take place.
       bool found=false;
       for (linear_inequality::lhs_t::const_iterator xj_it=working_equalities[xi].begin();
            xj_it!=working_equalities[xi].end(); ++xj_it)
       {
         const variable xj=xj_it->first;
-        // std::cerr << pp(xj) << "  --  " << pp(xj_it->second) <<  " POS " <<
+        // mCRL2log(debug) << pp(xj) << "  --  " << pp(xj_it->second) <<  " POS " <<
         //                 is_positive(xj_it->second,r) << "\n";
         if ((is_negative(xj_it->second,r) &&
              ((upperbounds.count(xj)==0) ||
@@ -1606,7 +1542,7 @@ inline bool is_inconsistent(
       if (!found)
       {
         // The inequalities are inconsistent.
-        mCRL2log(debug) << "Inconsistent while pivoting (1)\n";
+        mCRL2log(log::debug) << "Inconsistent while pivoting (1)\n";
         return true;
       }
     }
@@ -1811,13 +1747,9 @@ inline data_expression rewrite_with_memory(
   atermpp::map < data_expression, data_expression > :: iterator i=rewrite_hash_table.find(t);
   if (i==rewrite_hash_table.end())
   {
-    // std::cerr << "Size of hash table: " << rewrite_hash_table.size() << "\n";
     data_expression t1=r(t);
-    // rewrite_hash_table[t]=t1;
-    // std::cerr << "Term " << pp(t) << "Result " << pp(t1) << "\n";
     return t1;
   }
-  // std::cerr << "Term " << pp(t) << "FROM HASH " << pp(i->second) << "\n";
   return i->second;
 }
 
