@@ -11,6 +11,7 @@
 
 #include <vector>
 #include <set>
+#include "markmanager.h"
 #include "vectors.h"
 
 class Transition;
@@ -25,7 +26,6 @@ class State
     void addLoop(Transition* trans);
     void addOutTransition(Transition* trans);
     void center();
-    void deselect();
 
     Cluster* getCluster() const;
     int getID();
@@ -44,18 +44,16 @@ class State
     Vector3D getLoopControl1() const;
     Vector3D getLoopControl2() const;
     int getRank() const;
-    bool isSimulated() const;
+    bool isSimulated() const { return simulationCount > 0; }
     bool isCentered() const;
     bool isDeadlock() const;
-    bool isSelected() const;
     bool hasTextures() const;
 
-    void addMatchedRule(int mr);
-    bool removeMatchedRule(int mr);
-    void getMatchedRules(std::vector< int > &mrs);
-    int getNumMatchedRules();
+    bool addMatchedRule(MarkRuleIndex index);
+    bool removeMatchedRule(MarkRuleIndex index);
+    const std::set<MarkRuleIndex> &getMatchedRules() const { return matchedRules; }
+    void clearMatchedRules() { matchedRules.clear(); }
 
-    void select();
     void setCluster(Cluster* c);
     void setPositionAngle(float a);
     void setPositionRadius(float r);
@@ -66,7 +64,8 @@ class State
     void setLoopControl2(Vector3D p);
     void setID(int id);
     void setRank(int r);
-    void setSimulated(bool simulated);
+    void increaseSimulation() { simulationCount++; }
+    void decreaseSimulation() { simulationCount--; }
 
     void setZoomLevel(const int i);
     int getZoomLevel() const;
@@ -78,7 +77,7 @@ class State
     std::vector< Transition* > inTransitions;
     std::vector< Transition* > loops;
     std::vector< Transition* > outTransitions;
-    std::set< int > matchedRules;
+    std::set< MarkRuleIndex > matchedRules;
     float positionAngle;
     float positionRadius;
     Vector3D positionAbs;
@@ -87,8 +86,7 @@ class State
     Vector3D loopControl1;
     Vector3D loopControl2;
     int rank;
-    bool simulated;
-    bool selected;
+    int simulationCount;
 };
 
 #endif //STATE_H
