@@ -1,7 +1,7 @@
-// Copyright (c) 2007, 2009 University of Twente
-// Copyright (c) 2007, 2009 Michael Weber <michaelw@cs.utwente.nl>
-// Copyright (c) 2009 Maks Verver <maksverver@geocities.com>
-// Copyright (c) 2009 Eindhoven University of Technology
+// Copyright (c) 2009-2011 University of Twente
+// Copyright (c) 2009-2011 Michael Weber <michaelw@cs.utwente.nl>
+// Copyright (c) 2009-2011 Maks Verver <maksverver@geocities.com>
+// Copyright (c) 2009-2011 Eindhoven University of Technology
 //
 // Distributed under the Boost Software License, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at
@@ -16,20 +16,14 @@
     aborted by calling aborted() in time-consuming procedures. */
 class Abortable
 {
-  public:
+public:
     //! Abort all abortable processes.
-    static void abort_all()
-    {
-      global_abort_ = true;
-    }
+    static void abort_all() { global_abort_ = true; }
 
     //! Returns whether this instance has been aborted.
-    bool aborted()
-    {
-      return global_abort_;
-    }
+    bool aborted() { return global_abort_; }
 
-  private:
+private:
     static volatile bool global_abort_;
 };
 
