@@ -1,7 +1,7 @@
-// Copyright (c) 2007, 2009 University of Twente
-// Copyright (c) 2007, 2009 Michael Weber <michaelw@cs.utwente.nl>
-// Copyright (c) 2009 Maks Verver <maksverver@geocities.com>
-// Copyright (c) 2009 Eindhoven University of Technology
+// Copyright (c) 2009-2011 University of Twente
+// Copyright (c) 2009-2011 Michael Weber <michaelw@cs.utwente.nl>
+// Copyright (c) 2009-2011 Maks Verver <maksverver@geocities.com>
+// Copyright (c) 2009-2011 Eindhoven University of Technology
 //
 // Distributed under the Boost Software License, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at
@@ -24,32 +24,29 @@
 
 /*! Traverses the graph in breadth-first search order, and returns the result
     in `perm', such that perm[v] = i if v is the i-th visited vertex. */
-void get_bfs_order(const StaticGraph& graph, std::vector<verti> &perm);
+void get_bfs_order(const StaticGraph &graph, std::vector<verti> &perm);
 
 /*! Traverses the graph in depth-first search order, and returns the result
     in `perm', such that perm[v] = i if v is the i-th visited vertex. */
-void get_dfs_order(const StaticGraph& graph, std::vector<verti> &perm);
+void get_dfs_order(const StaticGraph &graph, std::vector<verti> &perm);
 
 /*! Count the number of edges with a specific ordering of vertices.
     An edge (i,j) is counted if sign(j - i) == sign(dir).*/
-edgei count_ordered_edges(const StaticGraph& g, int dir);
+edgei count_ordered_edges(const StaticGraph &g, int dir);
 
 /*! Returns the number of edges (i,j) such that i &lt; j */
-inline edgei count_forward_edges(const StaticGraph& g)
-{
-  return count_ordered_edges(g, +1);
+inline edgei count_forward_edges(const StaticGraph &g) {
+    return count_ordered_edges(g, +1);
 }
 
 /*! Returns the number of edges (i,j) such that i &gt; j */
-inline edgei count_backward_edges(const StaticGraph& g)
-{
-  return count_ordered_edges(g, -1);
+inline edgei count_backward_edges(const StaticGraph &g) {
+    return count_ordered_edges(g, -1);
 }
 
 /*! Returns the number of edges (i,j) such that i = j */
-inline edgei counts_self_edges(const StaticGraph& g)
-{
-  return count_ordered_edges(g, 0);
+inline edgei counts_self_edges(const StaticGraph &g) {
+    return count_ordered_edges(g, 0);
 }
 
 #endif /* ndef GRAPH_ORDERING_H_INCLUDED */
