@@ -18,8 +18,7 @@
 #include <fstream>
 #include <iostream>
 #include <string>
-#include "mcrl2/lps/parse.h"
-#include "mcrl2/lps/specification.h"
+#include "mcrl2/lps/tools.h"
 #include "mcrl2/utilities/input_output_tool.h"
 #include "mcrl2/utilities/mcrl2_gui_tool.h"
 #include "mcrl2/atermpp/aterm_init.h"
@@ -45,22 +44,9 @@ class txt2lps_tool : public input_output_tool
 
     bool run()
     {
-      lps::specification spec;
-
-      if (input_filename().empty())
-      {
-        spec = lps::parse_linear_process_specification(std::cin);
-      }
-      else
-      {
-        std::ifstream from(input_filename().c_str());
-        if (!from)
-        {
-          throw mcrl2::runtime_error("Could not read from input file: " + input_filename());
-        }
-        spec = lps::parse_linear_process_specification(from);
-      }
-      spec.save(output_filename());
+      lps::txtlps(input_filename(),
+                  output_filename()
+                 );
       return true;
     }
 
